import java
import java.chaquopy
import java.lang
import java.security
import java.security.spec

class HpkeSpi(java.lang.Object):
    def engineExport(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...
    def engineInitRecipient(self, arg1: java.chaquopy.JavaArrayJByte, arg2: java.security.PrivateKey, arg3: java.chaquopy.JavaArrayJByte, arg4: java.security.PublicKey, arg5: java.chaquopy.JavaArrayJByte, arg6: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def engineInitSender(self, arg1: java.security.PublicKey, arg2: java.chaquopy.JavaArrayJByte, arg3: java.security.PrivateKey, arg4: java.chaquopy.JavaArrayJByte, arg5: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def engineInitSenderWithSeed(self, arg1: java.security.PublicKey, arg2: java.chaquopy.JavaArrayJByte, arg3: java.security.PrivateKey, arg4: java.chaquopy.JavaArrayJByte, arg5: java.chaquopy.JavaArrayJByte, arg6: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def engineOpen(self, arg1: java.chaquopy.JavaArrayJByte, arg2: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...
    def engineSeal(self, arg1: java.chaquopy.JavaArrayJByte, arg2: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...
    def getEncapsulated(self) -> java.chaquopy.JavaArrayJByte: ...

class XdhKeySpec(java.security.spec.EncodedKeySpec):
    def __init__(self, encoded: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getFormat(self) -> str: ...
    def getKey(self) -> java.chaquopy.JavaArrayJByte: ...
    def hashCode(self) -> int: ...



import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.math
import java.net
import java.security
import java.util
import javax.security.auth.x500

class CRL(java.lang.Object):
    def __init__(self, type: str | java.lang.String, /) -> None: ...
    def getType(self) -> str: ...
    def isRevoked(self, arg1: Certificate, /) -> bool: ...
    def toString(self) -> str: ...

class CRLException(java.security.GeneralSecurityException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class CRLReason(java.lang.Enum[CRLReason]):
    AA_COMPROMISE: typing.ClassVar[CRLReason] = ...
    AFFILIATION_CHANGED: typing.ClassVar[CRLReason] = ...
    CA_COMPROMISE: typing.ClassVar[CRLReason] = ...
    CERTIFICATE_HOLD: typing.ClassVar[CRLReason] = ...
    CESSATION_OF_OPERATION: typing.ClassVar[CRLReason] = ...
    KEY_COMPROMISE: typing.ClassVar[CRLReason] = ...
    PRIVILEGE_WITHDRAWN: typing.ClassVar[CRLReason] = ...
    REMOVE_FROM_CRL: typing.ClassVar[CRLReason] = ...
    SUPERSEDED: typing.ClassVar[CRLReason] = ...
    UNSPECIFIED: typing.ClassVar[CRLReason] = ...
    UNUSED: typing.ClassVar[CRLReason] = ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> CRLReason: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[CRLReason]: ...

class CRLSelector(java.lang.Cloneable):
    def clone(self) -> java.lang.Object: ...
    def match(self, arg1: CRL, /) -> bool: ...

class CertPath(java.io.Serializable):
    def __init__(self, type: str | java.lang.String, /) -> None: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCertificates(self) -> java.util.List[Certificate]: ...
    @typing.overload
    def getEncoded(self) -> java.chaquopy.JavaArrayJByte: ...
    @typing.overload
    def getEncoded(self, arg1: str | java.lang.String, /) -> java.chaquopy.JavaArrayJByte: ...
    def getEncodings(self) -> java.util.Iterator[java.lang.String]: ...
    def getType(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeReplace(self) -> java.lang.Object: ...

    class CertPathRep(java.io.Serializable):
        def __init__(self, type: str | java.lang.String, data: java.chaquopy.JavaArrayJByte, /) -> None: ...
        def readResolve(self) -> java.lang.Object: ...

class CertPathBuilder(java.lang.Object):
    def __init__(self, builderSpi: CertPathBuilderSpi, provider: java.security.Provider, algorithm: str | java.lang.String, /) -> None: ...
    def build(self, params: CertPathParameters, /) -> CertPathBuilderResult: ...
    def getAlgorithm(self) -> str: ...
    @staticmethod
    def getDefaultType() -> str: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, /) -> CertPathBuilder: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, provider: str | java.lang.String, /) -> CertPathBuilder: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, provider: java.security.Provider, /) -> CertPathBuilder: ...
    def getProvider(self) -> java.security.Provider: ...
    def getRevocationChecker(self) -> CertPathChecker: ...

class CertPathBuilderException(java.security.GeneralSecurityException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class CertPathBuilderResult(java.lang.Cloneable):
    def clone(self) -> java.lang.Object: ...
    def getCertPath(self) -> CertPath: ...

class CertPathBuilderSpi(java.lang.Object):
    def __init__(self) -> None: ...
    def engineBuild(self, arg1: CertPathParameters, /) -> CertPathBuilderResult: ...
    def engineGetRevocationChecker(self) -> CertPathChecker: ...

class CertPathChecker(java.lang.Object):
    def check(self, arg1: Certificate, /) -> None: ...
    def init(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def isForwardCheckingSupported(self) -> bool: ...

class CertPathParameters(java.lang.Cloneable):
    def clone(self) -> java.lang.Object: ...

class CertPathValidator(java.lang.Object):
    def __init__(self, validatorSpi: CertPathValidatorSpi, provider: java.security.Provider, algorithm: str | java.lang.String, /) -> None: ...
    def getAlgorithm(self) -> str: ...
    @staticmethod
    def getDefaultType() -> str: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, /) -> CertPathValidator: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, provider: str | java.lang.String, /) -> CertPathValidator: ...
    @typing.overload
    @staticmethod
    def getInstance(algorithm: str | java.lang.String, provider: java.security.Provider, /) -> CertPathValidator: ...
    def getProvider(self) -> java.security.Provider: ...
    def getRevocationChecker(self) -> CertPathChecker: ...
    def validate(self, certPath: CertPath, params: CertPathParameters, /) -> CertPathValidatorResult: ...

class CertPathValidatorException(java.security.GeneralSecurityException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, cause: java.lang.Throwable, certPath: CertPath, index: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, cause: java.lang.Throwable, certPath: CertPath, index: int | java.jint | java.lang.Integer, reason: CertPathValidatorException.Reason, /) -> None: ...
    def getCertPath(self) -> CertPath: ...
    def getIndex(self) -> int: ...
    def getReason(self) -> CertPathValidatorException.Reason: ...

    class Reason(java.io.Serializable): ...

    class BasicReason(java.lang.Enum[CertPathValidatorException.BasicReason], CertPathValidatorException.Reason):
        ALGORITHM_CONSTRAINED: typing.ClassVar[CertPathValidatorException.BasicReason] = ...
        EXPIRED: typing.ClassVar[CertPathValidatorException.BasicReason] = ...
        INVALID_SIGNATURE: typing.ClassVar[CertPathValidatorException.BasicReason] = ...
        NOT_YET_VALID: typing.ClassVar[CertPathValidatorException.BasicReason] = ...
        REVOKED: typing.ClassVar[CertPathValidatorException.BasicReason] = ...
        UNDETERMINED_REVOCATION_STATUS: typing.ClassVar[CertPathValidatorException.BasicReason] = ...
        UNSPECIFIED: typing.ClassVar[CertPathValidatorException.BasicReason] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> CertPathValidatorException.BasicReason: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[CertPathValidatorException.BasicReason]: ...

class CertPathValidatorResult(java.lang.Cloneable):
    def clone(self) -> java.lang.Object: ...

class CertPathValidatorSpi(java.lang.Object):
    def __init__(self) -> None: ...
    def engineGetRevocationChecker(self) -> CertPathChecker: ...
    def engineValidate(self, arg1: CertPath, arg2: CertPathParameters, /) -> CertPathValidatorResult: ...

class CertSelector(java.lang.Cloneable):
    def clone(self) -> java.lang.Object: ...
    def match(self, arg1: Certificate, /) -> bool: ...

class CertStore(java.lang.Object):
    def __init__(self, storeSpi: CertStoreSpi, provider: java.security.Provider, type: str | java.lang.String, params: CertStoreParameters, /) -> None: ...
    def getCRLs(self, selector: CRLSelector, /) -> java.util.Collection[CRL]: ...
    def getCertStoreParameters(self) -> CertStoreParameters: ...
    def getCertificates(self, selector: CertSelector, /) -> java.util.Collection[Certificate]: ...
    @staticmethod
    def getDefaultType() -> str: ...
    @typing.overload
    @staticmethod
    def getInstance(type: str | java.lang.String, params: CertStoreParameters, /) -> CertStore: ...
    @typing.overload
    @staticmethod
    def getInstance(type: str | java.lang.String, params: CertStoreParameters, provider: str | java.lang.String, /) -> CertStore: ...
    @typing.overload
    @staticmethod
    def getInstance(type: str | java.lang.String, params: CertStoreParameters, provider: java.security.Provider, /) -> CertStore: ...
    def getProvider(self) -> java.security.Provider: ...
    def getType(self) -> str: ...

class CertStoreException(java.security.GeneralSecurityException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class CertStoreParameters(java.lang.Cloneable):
    def clone(self) -> java.lang.Object: ...

class CertStoreSpi(java.lang.Object):
    def __init__(self, params: CertStoreParameters, /) -> None: ...
    def engineGetCRLs(self, arg1: CRLSelector, /) -> java.util.Collection[CRL]: ...
    def engineGetCertificates(self, arg1: CertSelector, /) -> java.util.Collection[Certificate]: ...

class Certificate(java.io.Serializable):
    def __init__(self, type: str | java.lang.String, /) -> None: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getEncoded(self) -> java.chaquopy.JavaArrayJByte: ...
    def getPublicKey(self) -> java.security.PublicKey: ...
    def getType(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    @typing.overload
    def verify(self, arg1: java.security.PublicKey, /) -> None: ...
    @typing.overload
    def verify(self, arg1: java.security.PublicKey, arg2: str | java.lang.String, /) -> None: ...
    @typing.overload
    def verify(self, key: java.security.PublicKey, sigProvider: java.security.Provider, /) -> None: ...
    def writeReplace(self) -> java.lang.Object: ...

    class CertificateRep(java.io.Serializable):
        def __init__(self, type: str | java.lang.String, data: java.chaquopy.JavaArrayJByte, /) -> None: ...
        def readResolve(self) -> java.lang.Object: ...

class CertificateEncodingException(CertificateException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class CertificateException(java.security.GeneralSecurityException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class CertificateExpiredException(CertificateException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...

class CertificateFactory(java.lang.Object):
    def __init__(self, certFacSpi: CertificateFactorySpi, provider: java.security.Provider, type: str | java.lang.String, /) -> None: ...
    def generateCRL(self, inStream: java.io.InputStream, /) -> CRL: ...
    def generateCRLs(self, inStream: java.io.InputStream, /) -> java.util.Collection[CRL]: ...
    @typing.overload
    def generateCertPath(self, inStream: java.io.InputStream, /) -> CertPath: ...
    @typing.overload
    def generateCertPath(self, certificates: java.util.List[Certificate], /) -> CertPath: ...
    @typing.overload
    def generateCertPath(self, inStream: java.io.InputStream, encoding: str | java.lang.String, /) -> CertPath: ...
    def generateCertificate(self, inStream: java.io.InputStream, /) -> Certificate: ...
    def generateCertificates(self, inStream: java.io.InputStream, /) -> java.util.Collection[Certificate]: ...
    def getCertPathEncodings(self) -> java.util.Iterator[java.lang.String]: ...
    @typing.overload
    @staticmethod
    def getInstance(type: str | java.lang.String, /) -> CertificateFactory: ...
    @typing.overload
    @staticmethod
    def getInstance(type: str | java.lang.String, provider: str | java.lang.String, /) -> CertificateFactory: ...
    @typing.overload
    @staticmethod
    def getInstance(type: str | java.lang.String, provider: java.security.Provider, /) -> CertificateFactory: ...
    def getProvider(self) -> java.security.Provider: ...
    def getType(self) -> str: ...

class CertificateFactorySpi(java.lang.Object):
    def __init__(self) -> None: ...
    def engineGenerateCRL(self, arg1: java.io.InputStream, /) -> CRL: ...
    def engineGenerateCRLs(self, arg1: java.io.InputStream, /) -> java.util.Collection[CRL]: ...
    @typing.overload
    def engineGenerateCertPath(self, inStream: java.io.InputStream, /) -> CertPath: ...
    @typing.overload
    def engineGenerateCertPath(self, certificates: java.util.List[Certificate], /) -> CertPath: ...
    @typing.overload
    def engineGenerateCertPath(self, inStream: java.io.InputStream, encoding: str | java.lang.String, /) -> CertPath: ...
    def engineGenerateCertificate(self, arg1: java.io.InputStream, /) -> Certificate: ...
    def engineGenerateCertificates(self, arg1: java.io.InputStream, /) -> java.util.Collection[Certificate]: ...
    def engineGetCertPathEncodings(self) -> java.util.Iterator[java.lang.String]: ...

class CertificateNotYetValidException(CertificateException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...

class CertificateParsingException(CertificateException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class CertificateRevokedException(CertificateException):
    def __init__(self, revocationDate: java.util.Date, reason: CRLReason, authority: javax.security.auth.x500.X500Principal, extensions: java.util.Map[java.lang.String, Extension], /) -> None: ...
    def getAuthorityName(self) -> javax.security.auth.x500.X500Principal: ...
    def getExtensions(self) -> java.util.Map[java.lang.String, Extension]: ...
    def getInvalidityDate(self) -> java.util.Date: ...
    def getMessage(self) -> str: ...
    def getRevocationDate(self) -> java.util.Date: ...
    def getRevocationReason(self) -> CRLReason: ...

class CollectionCertStoreParameters(CertStoreParameters):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, collection: java.util.Collection[java.lang.Object], /) -> None: ...
    def clone(self) -> java.lang.Object: ...
    def getCollection(self) -> java.util.Collection[java.lang.Object]: ...
    def toString(self) -> str: ...

class Extension(java.lang.Object):
    def encode(self, arg1: java.io.OutputStream, /) -> None: ...
    def getId(self) -> str: ...
    def getValue(self) -> java.chaquopy.JavaArrayJByte: ...
    def isCritical(self) -> bool: ...

class LDAPCertStoreParameters(CertStoreParameters):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, serverName: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, serverName: str | java.lang.String, port: int | java.jint | java.lang.Integer, /) -> None: ...
    def clone(self) -> java.lang.Object: ...
    def getPort(self) -> int: ...
    def getServerName(self) -> str: ...
    def toString(self) -> str: ...

class PKIXBuilderParameters(PKIXParameters):
    @typing.overload
    def __init__(self, keystore: java.security.KeyStore, targetConstraints: CertSelector, /) -> None: ...
    @typing.overload
    def __init__(self, trustAnchors: java.util.Set[TrustAnchor], targetConstraints: CertSelector, /) -> None: ...
    def getMaxPathLength(self) -> int: ...
    def setMaxPathLength(self, maxPathLength: int | java.jint | java.lang.Integer, /) -> None: ...
    def toString(self) -> str: ...

class PKIXCertPathBuilderResult(CertPathBuilderResult, PKIXCertPathValidatorResult):
    def __init__(self, certPath: CertPath, trustAnchor: TrustAnchor, policyTree: PolicyNode, subjectPublicKey: java.security.PublicKey, /) -> None: ...
    def getCertPath(self) -> CertPath: ...
    def toString(self) -> str: ...

class PKIXCertPathChecker(CertPathChecker, java.lang.Cloneable):
    def __init__(self) -> None: ...
    @typing.overload
    def check(self, cert: Certificate, /) -> None: ...
    @typing.overload
    def check(self, arg1: Certificate, arg2: java.util.Collection[java.lang.String], /) -> None: ...
    def clone(self) -> java.lang.Object: ...
    def getSupportedExtensions(self) -> java.util.Set[java.lang.String]: ...
    def init(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def isForwardCheckingSupported(self) -> bool: ...

class PKIXCertPathValidatorResult(CertPathValidatorResult):
    def __init__(self, trustAnchor: TrustAnchor, policyTree: PolicyNode, subjectPublicKey: java.security.PublicKey, /) -> None: ...
    def clone(self) -> java.lang.Object: ...
    def getPolicyTree(self) -> PolicyNode: ...
    def getPublicKey(self) -> java.security.PublicKey: ...
    def getTrustAnchor(self) -> TrustAnchor: ...
    def toString(self) -> str: ...

class PKIXParameters(CertPathParameters):
    @typing.overload
    def __init__(self, keystore: java.security.KeyStore, /) -> None: ...
    @typing.overload
    def __init__(self, trustAnchors: java.util.Set[TrustAnchor], /) -> None: ...
    def addCertPathChecker(self, checker: PKIXCertPathChecker, /) -> None: ...
    def addCertStore(self, store: CertStore, /) -> None: ...
    def clone(self) -> java.lang.Object: ...
    def getCertPathCheckers(self) -> java.util.List[PKIXCertPathChecker]: ...
    def getCertStores(self) -> java.util.List[CertStore]: ...
    def getDate(self) -> java.util.Date: ...
    def getInitialPolicies(self) -> java.util.Set[java.lang.String]: ...
    def getPolicyQualifiersRejected(self) -> bool: ...
    def getSigProvider(self) -> str: ...
    def getTargetCertConstraints(self) -> CertSelector: ...
    def getTrustAnchors(self) -> java.util.Set[TrustAnchor]: ...
    def isAnyPolicyInhibited(self) -> bool: ...
    def isExplicitPolicyRequired(self) -> bool: ...
    def isPolicyMappingInhibited(self) -> bool: ...
    def isRevocationEnabled(self) -> bool: ...
    def setAnyPolicyInhibited(self, val: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setCertPathCheckers(self, checkers: java.util.List[PKIXCertPathChecker], /) -> None: ...
    def setCertStores(self, stores: java.util.List[CertStore], /) -> None: ...
    def setDate(self, date: java.util.Date, /) -> None: ...
    def setExplicitPolicyRequired(self, val: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setInitialPolicies(self, initialPolicies: java.util.Set[java.lang.String], /) -> None: ...
    def setPolicyMappingInhibited(self, val: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setPolicyQualifiersRejected(self, qualifiersRejected: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setRevocationEnabled(self, val: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSigProvider(self, sigProvider: str | java.lang.String, /) -> None: ...
    def setTargetCertConstraints(self, selector: CertSelector, /) -> None: ...
    def setTrustAnchors(self, trustAnchors: java.util.Set[TrustAnchor], /) -> None: ...
    def toString(self) -> str: ...

class PKIXReason(java.lang.Enum[PKIXReason], CertPathValidatorException.Reason):
    INVALID_KEY_USAGE: typing.ClassVar[PKIXReason] = ...
    INVALID_NAME: typing.ClassVar[PKIXReason] = ...
    INVALID_POLICY: typing.ClassVar[PKIXReason] = ...
    NAME_CHAINING: typing.ClassVar[PKIXReason] = ...
    NOT_CA_CERT: typing.ClassVar[PKIXReason] = ...
    NO_TRUST_ANCHOR: typing.ClassVar[PKIXReason] = ...
    PATH_TOO_LONG: typing.ClassVar[PKIXReason] = ...
    UNRECOGNIZED_CRIT_EXT: typing.ClassVar[PKIXReason] = ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> PKIXReason: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[PKIXReason]: ...

class PKIXRevocationChecker(PKIXCertPathChecker):
    def __init__(self) -> None: ...
    def clone(self) -> PKIXRevocationChecker: ...
    def getOcspExtensions(self) -> java.util.List[Extension]: ...
    def getOcspResponder(self) -> java.net.URI: ...
    def getOcspResponderCert(self) -> X509Certificate: ...
    def getOcspResponses(self) -> java.util.Map[X509Certificate, java.chaquopy.JavaArrayJByte]: ...
    def getOptions(self) -> java.util.Set[PKIXRevocationChecker.Option]: ...
    def getSoftFailExceptions(self) -> java.util.List[CertPathValidatorException]: ...
    def setOcspExtensions(self, extensions: java.util.List[Extension], /) -> None: ...
    def setOcspResponder(self, uri: java.net.URI, /) -> None: ...
    def setOcspResponderCert(self, cert: X509Certificate, /) -> None: ...
    def setOcspResponses(self, responses: java.util.Map[X509Certificate, java.chaquopy.JavaArrayJByte], /) -> None: ...
    def setOptions(self, options: java.util.Set[PKIXRevocationChecker.Option], /) -> None: ...

    class Option(java.lang.Enum[PKIXRevocationChecker.Option]):
        NO_FALLBACK: typing.ClassVar[PKIXRevocationChecker.Option] = ...
        ONLY_END_ENTITY: typing.ClassVar[PKIXRevocationChecker.Option] = ...
        PREFER_CRLS: typing.ClassVar[PKIXRevocationChecker.Option] = ...
        SOFT_FAIL: typing.ClassVar[PKIXRevocationChecker.Option] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> PKIXRevocationChecker.Option: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[PKIXRevocationChecker.Option]: ...

class PolicyNode(java.lang.Object):
    def getChildren(self) -> java.util.Iterator[PolicyNode]: ...
    def getDepth(self) -> int: ...
    def getExpectedPolicies(self) -> java.util.Set[java.lang.String]: ...
    def getParent(self) -> PolicyNode: ...
    def getPolicyQualifiers(self) -> java.util.Set[PolicyQualifierInfo]: ...
    def getValidPolicy(self) -> str: ...
    def isCritical(self) -> bool: ...

class PolicyQualifierInfo(java.lang.Object):
    def __init__(self, encoded: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def getEncoded(self) -> java.chaquopy.JavaArrayJByte: ...
    def getPolicyQualifier(self) -> java.chaquopy.JavaArrayJByte: ...
    def getPolicyQualifierId(self) -> str: ...
    def toString(self) -> str: ...

class TrustAnchor(java.lang.Object):
    @typing.overload
    def __init__(self, trustedCert: X509Certificate, nameConstraints: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def __init__(self, caName: str | java.lang.String, pubKey: java.security.PublicKey, nameConstraints: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def __init__(self, caPrincipal: javax.security.auth.x500.X500Principal, pubKey: java.security.PublicKey, nameConstraints: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def getCA(self) -> javax.security.auth.x500.X500Principal: ...
    def getCAName(self) -> str: ...
    def getCAPublicKey(self) -> java.security.PublicKey: ...
    def getNameConstraints(self) -> java.chaquopy.JavaArrayJByte: ...
    def getTrustedCert(self) -> X509Certificate: ...
    def toString(self) -> str: ...

class URICertStoreParameters(CertStoreParameters):
    def __init__(self, uri: java.net.URI, /) -> None: ...
    def clone(self) -> URICertStoreParameters: ...
    def equals(self, p: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getURI(self) -> java.net.URI: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class X509CRL(CRL, X509Extension):
    def __init__(self) -> None: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getEncoded(self) -> java.chaquopy.JavaArrayJByte: ...
    def getIssuerDN(self) -> java.security.Principal: ...
    def getIssuerX500Principal(self) -> javax.security.auth.x500.X500Principal: ...
    def getNextUpdate(self) -> java.util.Date: ...
    @typing.overload
    def getRevokedCertificate(self, arg1: java.math.BigInteger, /) -> X509CRLEntry: ...
    @typing.overload
    def getRevokedCertificate(self, certificate: X509Certificate, /) -> X509CRLEntry: ...
    def getRevokedCertificates(self) -> java.util.Set[X509CRLEntry]: ...
    def getSigAlgName(self) -> str: ...
    def getSigAlgOID(self) -> str: ...
    def getSigAlgParams(self) -> java.chaquopy.JavaArrayJByte: ...
    def getSignature(self) -> java.chaquopy.JavaArrayJByte: ...
    def getTBSCertList(self) -> java.chaquopy.JavaArrayJByte: ...
    def getThisUpdate(self) -> java.util.Date: ...
    def getVersion(self) -> int: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def verify(self, arg1: java.security.PublicKey, /) -> None: ...
    @typing.overload
    def verify(self, arg1: java.security.PublicKey, arg2: str | java.lang.String, /) -> None: ...
    @typing.overload
    def verify(self, key: java.security.PublicKey, sigProvider: java.security.Provider, /) -> None: ...

class X509CRLEntry(X509Extension):
    def __init__(self) -> None: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCertificateIssuer(self) -> javax.security.auth.x500.X500Principal: ...
    def getEncoded(self) -> java.chaquopy.JavaArrayJByte: ...
    def getRevocationDate(self) -> java.util.Date: ...
    def getRevocationReason(self) -> CRLReason: ...
    def getSerialNumber(self) -> java.math.BigInteger: ...
    def hasExtensions(self) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class X509CRLSelector(CRLSelector):
    def __init__(self) -> None: ...
    def addIssuer(self, issuer: javax.security.auth.x500.X500Principal, /) -> None: ...
    @typing.overload
    def addIssuerName(self, name: str | java.lang.String, /) -> None: ...
    @typing.overload
    def addIssuerName(self, name: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def clone(self) -> java.lang.Object: ...
    def getCertificateChecking(self) -> X509Certificate: ...
    def getDateAndTime(self) -> java.util.Date: ...
    def getIssuerNames(self) -> java.util.Collection[java.lang.Object]: ...
    def getIssuers(self) -> java.util.Collection[javax.security.auth.x500.X500Principal]: ...
    def getMaxCRL(self) -> java.math.BigInteger: ...
    def getMinCRL(self) -> java.math.BigInteger: ...
    def match(self, crl: CRL, /) -> bool: ...
    def setCertificateChecking(self, cert: X509Certificate, /) -> None: ...
    def setDateAndTime(self, dateAndTime: java.util.Date, /) -> None: ...
    def setIssuerNames(self, names: java.util.Collection[java.lang.Object], /) -> None: ...
    def setIssuers(self, issuers: java.util.Collection[javax.security.auth.x500.X500Principal], /) -> None: ...
    def setMaxCRLNumber(self, maxCRL: java.math.BigInteger, /) -> None: ...
    def setMinCRLNumber(self, minCRL: java.math.BigInteger, /) -> None: ...
    def toString(self) -> str: ...

class X509CertSelector(CertSelector):
    def __init__(self) -> None: ...
    @typing.overload
    def addPathToName(self, type: int | java.jint | java.lang.Integer, name: str | java.lang.String, /) -> None: ...
    @typing.overload
    def addPathToName(self, type: int | java.jint | java.lang.Integer, name: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def addSubjectAlternativeName(self, type: int | java.jint | java.lang.Integer, name: str | java.lang.String, /) -> None: ...
    @typing.overload
    def addSubjectAlternativeName(self, type: int | java.jint | java.lang.Integer, name: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def clone(self) -> java.lang.Object: ...
    def getAuthorityKeyIdentifier(self) -> java.chaquopy.JavaArrayJByte: ...
    def getBasicConstraints(self) -> int: ...
    def getCertificate(self) -> X509Certificate: ...
    def getCertificateValid(self) -> java.util.Date: ...
    def getExtendedKeyUsage(self) -> java.util.Set[java.lang.String]: ...
    def getIssuer(self) -> javax.security.auth.x500.X500Principal: ...
    def getIssuerAsBytes(self) -> java.chaquopy.JavaArrayJByte: ...
    def getIssuerAsString(self) -> str: ...
    def getKeyUsage(self) -> java.chaquopy.JavaArrayJBoolean: ...
    def getMatchAllSubjectAltNames(self) -> bool: ...
    def getNameConstraints(self) -> java.chaquopy.JavaArrayJByte: ...
    def getPathToNames(self) -> java.util.Collection[java.util.List[java.lang.Object]]: ...
    def getPolicy(self) -> java.util.Set[java.lang.String]: ...
    def getPrivateKeyValid(self) -> java.util.Date: ...
    def getSerialNumber(self) -> java.math.BigInteger: ...
    def getSubject(self) -> javax.security.auth.x500.X500Principal: ...
    def getSubjectAlternativeNames(self) -> java.util.Collection[java.util.List[java.lang.Object]]: ...
    def getSubjectAsBytes(self) -> java.chaquopy.JavaArrayJByte: ...
    def getSubjectAsString(self) -> str: ...
    def getSubjectKeyIdentifier(self) -> java.chaquopy.JavaArrayJByte: ...
    def getSubjectPublicKey(self) -> java.security.PublicKey: ...
    def getSubjectPublicKeyAlgID(self) -> str: ...
    def match(self, cert: Certificate, /) -> bool: ...
    def setAuthorityKeyIdentifier(self, authorityKeyID: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def setBasicConstraints(self, minMaxPathLen: int | java.jint | java.lang.Integer, /) -> None: ...
    def setCertificate(self, cert: X509Certificate, /) -> None: ...
    def setCertificateValid(self, certValid: java.util.Date, /) -> None: ...
    def setExtendedKeyUsage(self, keyPurposeSet: java.util.Set[java.lang.String], /) -> None: ...
    @typing.overload
    def setIssuer(self, issuerDN: str | java.lang.String, /) -> None: ...
    @typing.overload
    def setIssuer(self, issuer: javax.security.auth.x500.X500Principal, /) -> None: ...
    @typing.overload
    def setIssuer(self, issuerDN: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def setKeyUsage(self, keyUsage: java.chaquopy.JavaArrayJBoolean, /) -> None: ...
    def setMatchAllSubjectAltNames(self, matchAllNames: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setNameConstraints(self, bytes: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def setPathToNames(self, names: java.util.Collection[java.util.List[java.lang.Object]], /) -> None: ...
    def setPolicy(self, certPolicySet: java.util.Set[java.lang.String], /) -> None: ...
    def setPrivateKeyValid(self, privateKeyValid: java.util.Date, /) -> None: ...
    def setSerialNumber(self, serial: java.math.BigInteger, /) -> None: ...
    @typing.overload
    def setSubject(self, subjectDN: str | java.lang.String, /) -> None: ...
    @typing.overload
    def setSubject(self, subject: javax.security.auth.x500.X500Principal, /) -> None: ...
    @typing.overload
    def setSubject(self, subjectDN: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def setSubjectAlternativeNames(self, names: java.util.Collection[java.util.List[java.lang.Object]], /) -> None: ...
    def setSubjectKeyIdentifier(self, subjectKeyID: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def setSubjectPublicKey(self, key: java.security.PublicKey, /) -> None: ...
    @typing.overload
    def setSubjectPublicKey(self, key: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def setSubjectPublicKeyAlgID(self, oid: str | java.lang.String, /) -> None: ...
    def toString(self) -> str: ...

class X509Certificate(Certificate, X509Extension):
    def __init__(self) -> None: ...
    @typing.overload
    def checkValidity(self) -> None: ...
    @typing.overload
    def checkValidity(self, arg1: java.util.Date, /) -> None: ...
    def getBasicConstraints(self) -> int: ...
    def getExtendedKeyUsage(self) -> java.util.List[java.lang.String]: ...
    def getIssuerAlternativeNames(self) -> java.util.Collection[java.util.List[java.lang.Object]]: ...
    def getIssuerDN(self) -> java.security.Principal: ...
    def getIssuerUniqueID(self) -> java.chaquopy.JavaArrayJBoolean: ...
    def getIssuerX500Principal(self) -> javax.security.auth.x500.X500Principal: ...
    def getKeyUsage(self) -> java.chaquopy.JavaArrayJBoolean: ...
    def getNotAfter(self) -> java.util.Date: ...
    def getNotBefore(self) -> java.util.Date: ...
    def getSerialNumber(self) -> java.math.BigInteger: ...
    def getSigAlgName(self) -> str: ...
    def getSigAlgOID(self) -> str: ...
    def getSigAlgParams(self) -> java.chaquopy.JavaArrayJByte: ...
    def getSignature(self) -> java.chaquopy.JavaArrayJByte: ...
    def getSubjectAlternativeNames(self) -> java.util.Collection[java.util.List[java.lang.Object]]: ...
    def getSubjectDN(self) -> java.security.Principal: ...
    def getSubjectUniqueID(self) -> java.chaquopy.JavaArrayJBoolean: ...
    def getSubjectX500Principal(self) -> javax.security.auth.x500.X500Principal: ...
    def getTBSCertificate(self) -> java.chaquopy.JavaArrayJByte: ...
    def getVersion(self) -> int: ...
    def verify(self, key: java.security.PublicKey, sigProvider: java.security.Provider, /) -> None: ...

class X509Extension(java.lang.Object):
    def getCriticalExtensionOIDs(self) -> java.util.Set[java.lang.String]: ...
    def getExtensionValue(self, arg1: str | java.lang.String, /) -> java.chaquopy.JavaArrayJByte: ...
    def getNonCriticalExtensionOIDs(self) -> java.util.Set[java.lang.String]: ...
    def hasUnsupportedCriticalExtension(self) -> bool: ...



import typing

import android.app
import android.content
import android.media.browse
import android.media.session
import android.os
import java
import java.chaquopy
import java.io
import java.lang
import java.util

class CameraPrewarmService(android.app.Service):
    def __init__(self) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onCooldown(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onPrewarm(self) -> None: ...
    def onUnbind(self, intent: android.content.Intent, /) -> bool: ...


_MediaBrowserService__Result__T = typing.TypeVar('_MediaBrowserService__Result__T')  # <T>
class MediaBrowserService(android.app.Service):
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def dump(self, fd: java.io.FileDescriptor, writer: java.io.PrintWriter, args: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def getBrowserRootHints(self) -> android.os.Bundle: ...
    def getCurrentBrowserInfo(self) -> android.media.session.MediaSessionManager.RemoteUserInfo: ...
    def getSessionToken(self) -> android.media.session.MediaSession.Token | None: ...
    @typing.overload
    def notifyChildrenChanged(self, parentId: str | java.lang.String, /) -> None: ...
    @typing.overload
    def notifyChildrenChanged(self, parentId: str | java.lang.String, options: android.os.Bundle, /) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onCreate(self) -> None: ...
    def onGetRoot(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, arg3: android.os.Bundle, /) -> MediaBrowserService.BrowserRoot | None: ...
    @typing.overload
    def onLoadChildren(self, arg1: str | java.lang.String, arg2: MediaBrowserService.Result[java.util.List[android.media.browse.MediaBrowser.MediaItem]], /) -> None: ...
    @typing.overload
    def onLoadChildren(self, parentId: str | java.lang.String, result: MediaBrowserService.Result[java.util.List[android.media.browse.MediaBrowser.MediaItem]], options: android.os.Bundle, /) -> None: ...
    def onLoadItem(self, itemId: str | java.lang.String, result: MediaBrowserService.Result[android.media.browse.MediaBrowser.MediaItem], /) -> None: ...
    def setSessionToken(self, token: android.media.session.MediaSession.Token, /) -> None: ...
    class Result(java.lang.Object, typing.Generic[_MediaBrowserService__Result__T]):
        def detach(self) -> None: ...
        def sendResult(self, result: _MediaBrowserService__Result__T, /) -> None: ...

    class BrowserRoot(java.lang.Object):
        EXTRA_OFFLINE: typing.ClassVar[str] = ...
        EXTRA_RECENT: typing.ClassVar[str] = ...
        EXTRA_SUGGESTED: typing.ClassVar[str] = ...
        def __init__(self, rootId: str | java.lang.String, extras: android.os.Bundle, /) -> None: ...
        def getExtras(self) -> android.os.Bundle: ...
        def getRootId(self) -> str: ...



import typing

import android.content
import android.os
import java
import java.chaquopy
import java.io
import java.lang

class BackupAgent(android.content.ContextWrapper):
    FLAG_CLIENT_SIDE_ENCRYPTION_ENABLED: typing.ClassVar[int] = ...
    FLAG_DEVICE_TO_DEVICE_TRANSFER: typing.ClassVar[int] = ...
    TYPE_DIRECTORY: typing.ClassVar[int] = ...
    TYPE_FILE: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def fullBackupFile(self, file: java.io.File, output: FullBackupDataOutput, /) -> None: ...
    def onBackup(self, arg1: android.os.ParcelFileDescriptor, arg2: BackupDataOutput, arg3: android.os.ParcelFileDescriptor, /) -> None: ...
    def onCreate(self) -> None: ...
    def onDestroy(self) -> None: ...
    def onFullBackup(self, data: FullBackupDataOutput, /) -> None: ...
    def onQuotaExceeded(self, backupDataBytes: int | java.jlong | java.lang.Long, quotaBytes: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def onRestore(self, arg1: BackupDataInput, arg2: int | java.jint | java.lang.Integer, arg3: android.os.ParcelFileDescriptor, /) -> None: ...
    @typing.overload
    def onRestore(self, data: BackupDataInput, appVersionCode: int | java.jlong | java.lang.Long, newState: android.os.ParcelFileDescriptor, /) -> None: ...
    def onRestoreFile(self, data: android.os.ParcelFileDescriptor, size: int | java.jlong | java.lang.Long, destination: java.io.File, type: int | java.jint | java.lang.Integer, mode: int | java.jlong | java.lang.Long, mtime: int | java.jlong | java.lang.Long, /) -> None: ...
    def onRestoreFinished(self) -> None: ...

class BackupAgentHelper(BackupAgent):
    def __init__(self) -> None: ...
    def addHelper(self, keyPrefix: str | java.lang.String, helper: BackupHelper, /) -> None: ...
    def onBackup(self, oldState: android.os.ParcelFileDescriptor, data: BackupDataOutput, newState: android.os.ParcelFileDescriptor, /) -> None: ...
    def onRestore(self, data: BackupDataInput, appVersionCode: int | java.jint | java.lang.Integer, newState: android.os.ParcelFileDescriptor, /) -> None: ...

class BackupDataInput(java.lang.Object):
    def finalize(self) -> None: ...
    def getDataSize(self) -> int: ...
    def getKey(self) -> str: ...
    def readEntityData(self, data: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, size: int | java.jint | java.lang.Integer, /) -> int: ...
    def readNextHeader(self) -> bool: ...
    def skipEntityData(self) -> None: ...

class BackupDataInputStream(java.io.InputStream):
    def getKey(self) -> str: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, /) -> int: ...
    @typing.overload
    def read(self, b: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, size: int | java.jint | java.lang.Integer, /) -> int: ...
    def size(self) -> int: ...

class BackupDataOutput(java.lang.Object):
    def finalize(self) -> None: ...
    def getQuota(self) -> int: ...
    def getTransportFlags(self) -> int: ...
    def writeEntityData(self, data: java.chaquopy.JavaArrayJByte, size: int | java.jint | java.lang.Integer, /) -> int: ...
    def writeEntityHeader(self, key: str | java.lang.String, dataSize: int | java.jint | java.lang.Integer, /) -> int: ...

class BackupHelper(java.lang.Object):
    def performBackup(self, arg1: android.os.ParcelFileDescriptor, arg2: BackupDataOutput, arg3: android.os.ParcelFileDescriptor, /) -> None: ...
    def restoreEntity(self, arg1: BackupDataInputStream, /) -> None: ...
    def writeNewStateDescription(self, arg1: android.os.ParcelFileDescriptor, /) -> None: ...

class BackupManager(java.lang.Object):
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def dataChanged(self) -> None: ...
    @typing.overload
    @staticmethod
    def dataChanged(packageName: str | java.lang.String, /) -> None: ...
    def getUserForAncestralSerialNumber(self, ancestralSerialNumber: int | java.jlong | java.lang.Long, /) -> android.os.UserHandle | None: ...
    def requestRestore(self, observer: RestoreObserver, /) -> int: ...

class FileBackupHelper(BackupHelper):
    def __init__(self, context: android.content.Context, /, *files: java.lang.String) -> None: ...
    def performBackup(self, oldState: android.os.ParcelFileDescriptor, data: BackupDataOutput, newState: android.os.ParcelFileDescriptor, /) -> None: ...
    def restoreEntity(self, data: BackupDataInputStream, /) -> None: ...
    def writeNewStateDescription(self, fd: android.os.ParcelFileDescriptor, /) -> None: ...

class FullBackupDataOutput(java.lang.Object):
    def getQuota(self) -> int: ...
    def getTransportFlags(self) -> int: ...

class RestoreObserver(java.lang.Object):
    def __init__(self) -> None: ...
    def onUpdate(self, nowBeingRestored: int | java.jint | java.lang.Integer, currentPackage: str | java.lang.String, /) -> None: ...
    def restoreFinished(self, error: int | java.jint | java.lang.Integer, /) -> None: ...
    def restoreStarting(self, numPackages: int | java.jint | java.lang.Integer, /) -> None: ...

class SharedPreferencesBackupHelper(BackupHelper):
    def __init__(self, context: android.content.Context, /, *prefGroups: java.lang.String) -> None: ...
    def performBackup(self, oldState: android.os.ParcelFileDescriptor, data: BackupDataOutput, newState: android.os.ParcelFileDescriptor, /) -> None: ...
    def restoreEntity(self, data: BackupDataInputStream, /) -> None: ...
    def writeNewStateDescription(self, fd: android.os.ParcelFileDescriptor, /) -> None: ...



import typing

import android.app
import android.content
import android.content.pm
import android.net
import android.os
import java
import java.chaquopy
import java.lang
import java.util

class Condition(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Condition]] = ...
    FLAG_RELEVANT_ALWAYS: typing.ClassVar[int] = ...
    FLAG_RELEVANT_NOW: typing.ClassVar[int] = ...
    SCHEME: typing.ClassVar[str] = ...
    SOURCE_CONTEXT: typing.ClassVar[int] = ...
    SOURCE_SCHEDULE: typing.ClassVar[int] = ...
    SOURCE_UNKNOWN: typing.ClassVar[int] = ...
    SOURCE_USER_ACTION: typing.ClassVar[int] = ...
    STATE_ERROR: typing.ClassVar[int] = ...
    STATE_FALSE: typing.ClassVar[int] = ...
    STATE_TRUE: typing.ClassVar[int] = ...
    STATE_UNKNOWN: typing.ClassVar[int] = ...
    flags: int = ...
    icon: int = ...
    id: android.net.Uri = ...
    line1: str = ...
    line2: str = ...
    source: int = ...
    state: int = ...
    summary: str = ...
    @typing.overload
    def __init__(self, source: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, id: android.net.Uri, summary: str | java.lang.String, state: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, id: android.net.Uri, summary: str | java.lang.String, state: int | java.jint | java.lang.Integer, source: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, id: android.net.Uri, summary: str | java.lang.String, line1: str | java.lang.String, line2: str | java.lang.String, icon: int | java.jint | java.lang.Integer, state: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, id: android.net.Uri, summary: str | java.lang.String, line1: str | java.lang.String, line2: str | java.lang.String, icon: int | java.jint | java.lang.Integer, state: int | java.jint | java.lang.Integer, source: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def copy(self) -> Condition: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    @staticmethod
    def isValidId(id: android.net.Uri, pkg: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def newId(context: android.content.Context, /) -> android.net.Uri.Builder: ...
    @staticmethod
    def relevanceToString(flags: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def stateToString(state: int | java.jint | java.lang.Integer, /) -> str: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ConditionProviderService(android.app.Service):
    EXTRA_RULE_ID: typing.ClassVar[str] = ...
    META_DATA_CONFIGURATION_ACTIVITY: typing.ClassVar[str] = ...
    META_DATA_RULE_INSTANCE_LIMIT: typing.ClassVar[str] = ...
    META_DATA_RULE_TYPE: typing.ClassVar[str] = ...
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def notifyCondition(self, condition: Condition, /) -> None: ...
    def notifyConditions(self, *conditions: Condition) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onConnected(self) -> None: ...
    def onRequestConditions(self, relevance: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSubscribe(self, arg1: android.net.Uri, /) -> None: ...
    def onUnsubscribe(self, arg1: android.net.Uri, /) -> None: ...
    @staticmethod
    def requestRebind(componentName: android.content.ComponentName, /) -> None: ...
    def requestUnbind(self) -> None: ...

class NotificationListenerService(android.app.Service):
    ACTION_SETTINGS_HOME: typing.ClassVar[str] = ...
    FLAG_FILTER_TYPE_ALERTING: typing.ClassVar[int] = ...
    FLAG_FILTER_TYPE_CONVERSATIONS: typing.ClassVar[int] = ...
    FLAG_FILTER_TYPE_ONGOING: typing.ClassVar[int] = ...
    FLAG_FILTER_TYPE_SILENT: typing.ClassVar[int] = ...
    HINT_HOST_DISABLE_CALL_EFFECTS: typing.ClassVar[int] = ...
    HINT_HOST_DISABLE_EFFECTS: typing.ClassVar[int] = ...
    HINT_HOST_DISABLE_NOTIFICATION_EFFECTS: typing.ClassVar[int] = ...
    INTERRUPTION_FILTER_ALARMS: typing.ClassVar[int] = ...
    INTERRUPTION_FILTER_ALL: typing.ClassVar[int] = ...
    INTERRUPTION_FILTER_NONE: typing.ClassVar[int] = ...
    INTERRUPTION_FILTER_PRIORITY: typing.ClassVar[int] = ...
    INTERRUPTION_FILTER_UNKNOWN: typing.ClassVar[int] = ...
    META_DATA_DEFAULT_AUTOBIND: typing.ClassVar[str] = ...
    META_DATA_DEFAULT_FILTER_TYPES: typing.ClassVar[str] = ...
    META_DATA_DISABLED_FILTER_TYPES: typing.ClassVar[str] = ...
    NOTIFICATION_CHANNEL_OR_GROUP_ADDED: typing.ClassVar[int] = ...
    NOTIFICATION_CHANNEL_OR_GROUP_DELETED: typing.ClassVar[int] = ...
    NOTIFICATION_CHANNEL_OR_GROUP_UPDATED: typing.ClassVar[int] = ...
    REASON_APP_CANCEL: typing.ClassVar[int] = ...
    REASON_APP_CANCEL_ALL: typing.ClassVar[int] = ...
    REASON_ASSISTANT_CANCEL: typing.ClassVar[int] = ...
    REASON_CANCEL: typing.ClassVar[int] = ...
    REASON_CANCEL_ALL: typing.ClassVar[int] = ...
    REASON_CHANNEL_BANNED: typing.ClassVar[int] = ...
    REASON_CHANNEL_REMOVED: typing.ClassVar[int] = ...
    REASON_CLEAR_DATA: typing.ClassVar[int] = ...
    REASON_CLICK: typing.ClassVar[int] = ...
    REASON_ERROR: typing.ClassVar[int] = ...
    REASON_GROUP_OPTIMIZATION: typing.ClassVar[int] = ...
    REASON_GROUP_SUMMARY_CANCELED: typing.ClassVar[int] = ...
    REASON_LISTENER_CANCEL: typing.ClassVar[int] = ...
    REASON_LISTENER_CANCEL_ALL: typing.ClassVar[int] = ...
    REASON_LOCKDOWN: typing.ClassVar[int] = ...
    REASON_PACKAGE_BANNED: typing.ClassVar[int] = ...
    REASON_PACKAGE_CHANGED: typing.ClassVar[int] = ...
    REASON_PACKAGE_SUSPENDED: typing.ClassVar[int] = ...
    REASON_PROFILE_TURNED_OFF: typing.ClassVar[int] = ...
    REASON_SNOOZED: typing.ClassVar[int] = ...
    REASON_TIMEOUT: typing.ClassVar[int] = ...
    REASON_UNAUTOBUNDLED: typing.ClassVar[int] = ...
    REASON_USER_STOPPED: typing.ClassVar[int] = ...
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    SUPPRESSED_EFFECT_SCREEN_OFF: typing.ClassVar[int] = ...
    SUPPRESSED_EFFECT_SCREEN_ON: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def attachBaseContext(self, base: android.content.Context, /) -> None: ...
    def cancelAllNotifications(self) -> None: ...
    @typing.overload
    def cancelNotification(self, key: str | java.lang.String, /) -> None: ...
    @typing.overload
    def cancelNotification(self, pkg: str | java.lang.String, tag: str | java.lang.String, id: int | java.jint | java.lang.Integer, /) -> None: ...
    def cancelNotifications(self, keys: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def clearRequestedListenerHints(self) -> None: ...
    def createConversationNotificationChannelForPackage(self, pkg: str | java.lang.String, user: android.os.UserHandle, parentChannelId: str | java.lang.String, conversationId: str | java.lang.String, /) -> android.app.NotificationChannel: ...
    @typing.overload
    def getActiveNotifications(self) -> java.chaquopy.JavaArray[StatusBarNotification]: ...
    @typing.overload
    def getActiveNotifications(self, keys: java.chaquopy.JavaArray[java.lang.String], /) -> java.chaquopy.JavaArray[StatusBarNotification]: ...
    def getCurrentInterruptionFilter(self) -> int: ...
    def getCurrentListenerHints(self) -> int: ...
    def getCurrentRanking(self) -> NotificationListenerService.RankingMap: ...
    def getNotificationChannelGroups(self, pkg: str | java.lang.String, user: android.os.UserHandle, /) -> java.util.List[android.app.NotificationChannelGroup]: ...
    def getNotificationChannels(self, pkg: str | java.lang.String, user: android.os.UserHandle, /) -> java.util.List[android.app.NotificationChannel]: ...
    def getSnoozedNotifications(self) -> java.chaquopy.JavaArray[StatusBarNotification]: ...
    def migrateNotificationFilter(self, defaultTypes: int | java.jint | java.lang.Integer, disallowedPkgs: java.util.List[java.lang.String], /) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    def onDestroy(self) -> None: ...
    def onInterruptionFilterChanged(self, interruptionFilter: int | java.jint | java.lang.Integer, /) -> None: ...
    def onListenerConnected(self) -> None: ...
    def onListenerDisconnected(self) -> None: ...
    def onListenerHintsChanged(self, hints: int | java.jint | java.lang.Integer, /) -> None: ...
    def onNotificationChannelGroupModified(self, pkg: str | java.lang.String, user: android.os.UserHandle, group: android.app.NotificationChannelGroup, modificationType: int | java.jint | java.lang.Integer, /) -> None: ...
    def onNotificationChannelModified(self, pkg: str | java.lang.String, user: android.os.UserHandle, channel: android.app.NotificationChannel, modificationType: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def onNotificationPosted(self, sbn: StatusBarNotification, /) -> None: ...
    @typing.overload
    def onNotificationPosted(self, sbn: StatusBarNotification, rankingMap: NotificationListenerService.RankingMap, /) -> None: ...
    def onNotificationRankingUpdate(self, rankingMap: NotificationListenerService.RankingMap, /) -> None: ...
    @typing.overload
    def onNotificationRemoved(self, sbn: StatusBarNotification, /) -> None: ...
    @typing.overload
    def onNotificationRemoved(self, sbn: StatusBarNotification, rankingMap: NotificationListenerService.RankingMap, /) -> None: ...
    @typing.overload
    def onNotificationRemoved(self, sbn: StatusBarNotification, rankingMap: NotificationListenerService.RankingMap, reason: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSilentStatusBarIconsVisibilityChanged(self, hideSilentStatusIcons: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def requestInterruptionFilter(self, interruptionFilter: int | java.jint | java.lang.Integer, /) -> None: ...
    def requestListenerHints(self, hints: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def requestRebind(componentName: android.content.ComponentName, /) -> None: ...
    @typing.overload
    def requestUnbind(self) -> None: ...
    @typing.overload
    @staticmethod
    def requestUnbind(componentName: android.content.ComponentName, /) -> None: ...
    def setNotificationsShown(self, keys: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def snoozeNotification(self, key: str | java.lang.String, durationMs: int | java.jlong | java.lang.Long, /) -> None: ...
    def updateNotificationChannel(self, pkg: str | java.lang.String, user: android.os.UserHandle, channel: android.app.NotificationChannel, /) -> None: ...

    class RankingMap(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[NotificationListenerService.RankingMap]] = ...
        def describeContents(self) -> int: ...
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getOrderedKeys(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
        def getRanking(self, key: str | java.lang.String, outRanking: NotificationListenerService.Ranking, /) -> bool: ...
        def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Ranking(java.lang.Object):
        USER_SENTIMENT_NEGATIVE: typing.ClassVar[int] = ...
        USER_SENTIMENT_NEUTRAL: typing.ClassVar[int] = ...
        USER_SENTIMENT_POSITIVE: typing.ClassVar[int] = ...
        VISIBILITY_NO_OVERRIDE: typing.ClassVar[int] = ...
        def __init__(self) -> None: ...
        def canBubble(self) -> bool: ...
        def canShowBadge(self) -> bool: ...
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getChannel(self) -> android.app.NotificationChannel: ...
        def getConversationShortcutInfo(self) -> android.content.pm.ShortcutInfo: ...
        def getImportance(self) -> int: ...
        def getImportanceExplanation(self) -> java.lang.CharSequence: ...
        def getKey(self) -> str: ...
        def getLastAudiblyAlertedMillis(self) -> int: ...
        def getLockscreenVisibilityOverride(self) -> int: ...
        def getOverrideGroupKey(self) -> str: ...
        def getRank(self) -> int: ...
        def getSmartActions(self) -> java.util.List[android.app.Notification.Action]: ...
        def getSmartReplies(self) -> java.util.List[java.lang.CharSequence]: ...
        def getSuppressedVisualEffects(self) -> int: ...
        def getUserSentiment(self) -> int: ...
        def isAmbient(self) -> bool: ...
        def isConversation(self) -> bool: ...
        def isSuspended(self) -> bool: ...
        def matchesInterruptionFilter(self) -> bool: ...

class StatusBarNotification(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[StatusBarNotification]] = ...
    @typing.overload
    def __init__(self, in_: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, pkg: str | java.lang.String, opPkg: str | java.lang.String, id: int | java.jint | java.lang.Integer, tag: str | java.lang.String, uid: int | java.jint | java.lang.Integer, initialPid: int | java.jint | java.lang.Integer, score: int | java.jint | java.lang.Integer, notification: android.app.Notification, user: android.os.UserHandle, postTime: int | java.jlong | java.lang.Long, /) -> None: ...
    def clone(self) -> StatusBarNotification: ...
    def describeContents(self) -> int: ...
    def getGroupKey(self) -> str: ...
    def getId(self) -> int: ...
    def getKey(self) -> str: ...
    def getNotification(self) -> android.app.Notification: ...
    def getOpPkg(self) -> str: ...
    def getOverrideGroupKey(self) -> str: ...
    def getPackageName(self) -> str: ...
    def getPostTime(self) -> int: ...
    def getTag(self) -> str: ...
    def getUid(self) -> int: ...
    def getUser(self) -> android.os.UserHandle: ...
    def getUserId(self) -> int: ...
    def isAppGroup(self) -> bool: ...
    def isClearable(self) -> bool: ...
    def isGroup(self) -> bool: ...
    def isOngoing(self) -> bool: ...
    def setOverrideGroupKey(self, overrideGroupKey: str | java.lang.String, /) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ZenDeviceEffects(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ZenDeviceEffects]] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    def shouldDimWallpaper(self) -> bool: ...
    def shouldDisplayGrayscale(self) -> bool: ...
    def shouldSuppressAmbientDisplay(self) -> bool: ...
    def shouldUseNightMode(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, zenDeviceEffects: ZenDeviceEffects, /) -> None: ...
        def build(self) -> ZenDeviceEffects: ...
        def setShouldDimWallpaper(self, dimWallpaper: bool | java.jboolean | java.lang.Boolean, /) -> ZenDeviceEffects.Builder: ...
        def setShouldDisplayGrayscale(self, grayscale: bool | java.jboolean | java.lang.Boolean, /) -> ZenDeviceEffects.Builder: ...
        def setShouldSuppressAmbientDisplay(self, suppressAmbientDisplay: bool | java.jboolean | java.lang.Boolean, /) -> ZenDeviceEffects.Builder: ...
        def setShouldUseNightMode(self, nightMode: bool | java.jboolean | java.lang.Boolean, /) -> ZenDeviceEffects.Builder: ...

class ZenPolicy(android.os.Parcelable):
    CONVERSATION_SENDERS_ANYONE: typing.ClassVar[int] = ...
    CONVERSATION_SENDERS_IMPORTANT: typing.ClassVar[int] = ...
    CONVERSATION_SENDERS_NONE: typing.ClassVar[int] = ...
    CONVERSATION_SENDERS_UNSET: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ZenPolicy]] = ...
    PEOPLE_TYPE_ANYONE: typing.ClassVar[int] = ...
    PEOPLE_TYPE_CONTACTS: typing.ClassVar[int] = ...
    PEOPLE_TYPE_NONE: typing.ClassVar[int] = ...
    PEOPLE_TYPE_STARRED: typing.ClassVar[int] = ...
    PEOPLE_TYPE_UNSET: typing.ClassVar[int] = ...
    STATE_ALLOW: typing.ClassVar[int] = ...
    STATE_DISALLOW: typing.ClassVar[int] = ...
    STATE_UNSET: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getPriorityCallSenders(self) -> int: ...
    def getPriorityCategoryAlarms(self) -> int: ...
    def getPriorityCategoryCalls(self) -> int: ...
    def getPriorityCategoryConversations(self) -> int: ...
    def getPriorityCategoryEvents(self) -> int: ...
    def getPriorityCategoryMedia(self) -> int: ...
    def getPriorityCategoryMessages(self) -> int: ...
    def getPriorityCategoryReminders(self) -> int: ...
    def getPriorityCategoryRepeatCallers(self) -> int: ...
    def getPriorityCategorySystem(self) -> int: ...
    def getPriorityChannelsAllowed(self) -> int: ...
    def getPriorityConversationSenders(self) -> int: ...
    def getPriorityMessageSenders(self) -> int: ...
    def getVisualEffectAmbient(self) -> int: ...
    def getVisualEffectBadge(self) -> int: ...
    def getVisualEffectFullScreenIntent(self) -> int: ...
    def getVisualEffectLights(self) -> int: ...
    def getVisualEffectNotificationList(self) -> int: ...
    def getVisualEffectPeek(self) -> int: ...
    def getVisualEffectStatusBar(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def allowAlarms(self, allow: bool | java.jboolean | java.lang.Boolean, /) -> ZenPolicy.Builder: ...
        def allowAllSounds(self) -> ZenPolicy.Builder: ...
        def allowCalls(self, audienceType: int | java.jint | java.lang.Integer, /) -> ZenPolicy.Builder: ...
        def allowConversations(self, audienceType: int | java.jint | java.lang.Integer, /) -> ZenPolicy.Builder: ...
        def allowEvents(self, allow: bool | java.jboolean | java.lang.Boolean, /) -> ZenPolicy.Builder: ...
        def allowMedia(self, allow: bool | java.jboolean | java.lang.Boolean, /) -> ZenPolicy.Builder: ...
        def allowMessages(self, audienceType: int | java.jint | java.lang.Integer, /) -> ZenPolicy.Builder: ...
        def allowPriorityChannels(self, allow: bool | java.jboolean | java.lang.Boolean, /) -> ZenPolicy.Builder: ...
        def allowReminders(self, allow: bool | java.jboolean | java.lang.Boolean, /) -> ZenPolicy.Builder: ...
        def allowRepeatCallers(self, allow: bool | java.jboolean | java.lang.Boolean, /) -> ZenPolicy.Builder: ...
        def allowSystem(self, allow: bool | java.jboolean | java.lang.Boolean, /) -> ZenPolicy.Builder: ...
        def build(self) -> ZenPolicy: ...
        def disallowAllSounds(self) -> ZenPolicy.Builder: ...
        def hideAllVisualEffects(self) -> ZenPolicy.Builder: ...
        def showAllVisualEffects(self) -> ZenPolicy.Builder: ...
        def showBadges(self, show: bool | java.jboolean | java.lang.Boolean, /) -> ZenPolicy.Builder: ...
        def showFullScreenIntent(self, show: bool | java.jboolean | java.lang.Boolean, /) -> ZenPolicy.Builder: ...
        def showInAmbientDisplay(self, show: bool | java.jboolean | java.lang.Boolean, /) -> ZenPolicy.Builder: ...
        def showInNotificationList(self, show: bool | java.jboolean | java.lang.Boolean, /) -> ZenPolicy.Builder: ...
        def showLights(self, show: bool | java.jboolean | java.lang.Boolean, /) -> ZenPolicy.Builder: ...
        def showPeeking(self, show: bool | java.jboolean | java.lang.Boolean, /) -> ZenPolicy.Builder: ...
        def showStatusBarIcons(self, show: bool | java.jboolean | java.lang.Boolean, /) -> ZenPolicy.Builder: ...



import typing

import android.os
import java
import java.lang
import java.util

class EmergencyNumber(android.os.Parcelable, java.lang.Comparable[EmergencyNumber]):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[EmergencyNumber]] = ...
    EMERGENCY_CALL_ROUTING_EMERGENCY: typing.ClassVar[int] = ...
    EMERGENCY_CALL_ROUTING_NORMAL: typing.ClassVar[int] = ...
    EMERGENCY_CALL_ROUTING_UNKNOWN: typing.ClassVar[int] = ...
    EMERGENCY_NUMBER_SOURCE_DATABASE: typing.ClassVar[int] = ...
    EMERGENCY_NUMBER_SOURCE_DEFAULT: typing.ClassVar[int] = ...
    EMERGENCY_NUMBER_SOURCE_MODEM_CONFIG: typing.ClassVar[int] = ...
    EMERGENCY_NUMBER_SOURCE_NETWORK_SIGNALING: typing.ClassVar[int] = ...
    EMERGENCY_NUMBER_SOURCE_SIM: typing.ClassVar[int] = ...
    EMERGENCY_SERVICE_CATEGORY_AIEC: typing.ClassVar[int] = ...
    EMERGENCY_SERVICE_CATEGORY_AMBULANCE: typing.ClassVar[int] = ...
    EMERGENCY_SERVICE_CATEGORY_FIRE_BRIGADE: typing.ClassVar[int] = ...
    EMERGENCY_SERVICE_CATEGORY_MARINE_GUARD: typing.ClassVar[int] = ...
    EMERGENCY_SERVICE_CATEGORY_MIEC: typing.ClassVar[int] = ...
    EMERGENCY_SERVICE_CATEGORY_MOUNTAIN_RESCUE: typing.ClassVar[int] = ...
    EMERGENCY_SERVICE_CATEGORY_POLICE: typing.ClassVar[int] = ...
    EMERGENCY_SERVICE_CATEGORY_UNSPECIFIED: typing.ClassVar[int] = ...
    def compareTo(self, emergencyNumber: EmergencyNumber, /) -> int: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCountryIso(self) -> str: ...
    def getEmergencyCallRouting(self) -> int: ...
    def getEmergencyNumberSources(self) -> java.util.List[java.lang.Integer]: ...
    def getEmergencyServiceCategories(self) -> java.util.List[java.lang.Integer]: ...
    def getEmergencyUrns(self) -> java.util.List[java.lang.String]: ...
    def getMnc(self) -> str: ...
    def getNumber(self) -> str: ...
    def hashCode(self) -> int: ...
    def isFromSources(self, sources: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isInEmergencyServiceCategories(self, categories: int | java.jint | java.lang.Integer, /) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.math
import java.net
import java.sql
import java.util
import java.util.logging

class CommonDataSource(java.lang.Object):
    def getLogWriter(self) -> java.io.PrintWriter: ...
    def getLoginTimeout(self) -> int: ...
    def getParentLogger(self) -> java.util.logging.Logger: ...
    def setLogWriter(self, arg1: java.io.PrintWriter, /) -> None: ...
    def setLoginTimeout(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

class ConnectionEvent(java.util.EventObject):
    @typing.overload
    def __init__(self, con: PooledConnection, /) -> None: ...
    @typing.overload
    def __init__(self, con: PooledConnection, ex: java.sql.SQLException, /) -> None: ...
    def getSQLException(self) -> java.sql.SQLException: ...

class ConnectionEventListener(java.util.EventListener):
    def connectionClosed(self, arg1: ConnectionEvent, /) -> None: ...
    def connectionErrorOccurred(self, arg1: ConnectionEvent, /) -> None: ...

class ConnectionPoolDataSource(CommonDataSource):
    @typing.overload
    def getPooledConnection(self) -> PooledConnection: ...
    @typing.overload
    def getPooledConnection(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> PooledConnection: ...

class DataSource(CommonDataSource, java.sql.Wrapper):
    @typing.overload
    def getConnection(self) -> java.sql.Connection: ...
    @typing.overload
    def getConnection(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> java.sql.Connection: ...

class PooledConnection(java.lang.Object):
    def addConnectionEventListener(self, arg1: ConnectionEventListener, /) -> None: ...
    def addStatementEventListener(self, arg1: StatementEventListener, /) -> None: ...
    def close(self) -> None: ...
    def getConnection(self) -> java.sql.Connection: ...
    def removeConnectionEventListener(self, arg1: ConnectionEventListener, /) -> None: ...
    def removeStatementEventListener(self, arg1: StatementEventListener, /) -> None: ...

class RowSet(java.sql.ResultSet):
    def addRowSetListener(self, arg1: RowSetListener, /) -> None: ...
    def clearParameters(self) -> None: ...
    def execute(self) -> None: ...
    def getCommand(self) -> str: ...
    def getDataSourceName(self) -> str: ...
    def getEscapeProcessing(self) -> bool: ...
    def getMaxFieldSize(self) -> int: ...
    def getMaxRows(self) -> int: ...
    def getPassword(self) -> str: ...
    def getQueryTimeout(self) -> int: ...
    def getTransactionIsolation(self) -> int: ...
    def getTypeMap(self) -> java.util.Map[java.lang.String, typing.Type[java.lang.Object]]: ...
    def getUrl(self) -> str: ...
    def getUsername(self) -> str: ...
    def isReadOnly(self) -> bool: ...
    def removeRowSetListener(self, arg1: RowSetListener, /) -> None: ...
    def setArray(self, arg1: int | java.jint | java.lang.Integer, arg2: java.sql.Array, /) -> None: ...
    @typing.overload
    def setAsciiStream(self, arg1: int | java.jint | java.lang.Integer, arg2: java.io.InputStream, /) -> None: ...
    @typing.overload
    def setAsciiStream(self, arg1: str | java.lang.String, arg2: java.io.InputStream, /) -> None: ...
    @typing.overload
    def setAsciiStream(self, arg1: int | java.jint | java.lang.Integer, arg2: java.io.InputStream, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setAsciiStream(self, arg1: str | java.lang.String, arg2: java.io.InputStream, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setBigDecimal(self, arg1: int | java.jint | java.lang.Integer, arg2: java.math.BigDecimal, /) -> None: ...
    @typing.overload
    def setBigDecimal(self, arg1: str | java.lang.String, arg2: java.math.BigDecimal, /) -> None: ...
    @typing.overload
    def setBinaryStream(self, arg1: int | java.jint | java.lang.Integer, arg2: java.io.InputStream, /) -> None: ...
    @typing.overload
    def setBinaryStream(self, arg1: str | java.lang.String, arg2: java.io.InputStream, /) -> None: ...
    @typing.overload
    def setBinaryStream(self, arg1: int | java.jint | java.lang.Integer, arg2: java.io.InputStream, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setBinaryStream(self, arg1: str | java.lang.String, arg2: java.io.InputStream, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setBlob(self, arg1: int | java.jint | java.lang.Integer, arg2: java.io.InputStream, /) -> None: ...
    @typing.overload
    def setBlob(self, arg1: int | java.jint | java.lang.Integer, arg2: java.sql.Blob, /) -> None: ...
    @typing.overload
    def setBlob(self, arg1: str | java.lang.String, arg2: java.io.InputStream, /) -> None: ...
    @typing.overload
    def setBlob(self, arg1: str | java.lang.String, arg2: java.sql.Blob, /) -> None: ...
    @typing.overload
    def setBlob(self, arg1: int | java.jint | java.lang.Integer, arg2: java.io.InputStream, arg3: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def setBlob(self, arg1: str | java.lang.String, arg2: java.io.InputStream, arg3: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def setBoolean(self, arg1: int | java.jint | java.lang.Integer, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setBoolean(self, arg1: str | java.lang.String, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setByte(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jbyte | java.lang.Byte, /) -> None: ...
    @typing.overload
    def setByte(self, arg1: str | java.lang.String, arg2: int | java.jbyte | java.lang.Byte, /) -> None: ...
    @typing.overload
    def setBytes(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def setBytes(self, arg1: str | java.lang.String, arg2: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def setCharacterStream(self, arg1: int | java.jint | java.lang.Integer, arg2: java.io.Reader, /) -> None: ...
    @typing.overload
    def setCharacterStream(self, arg1: str | java.lang.String, arg2: java.io.Reader, /) -> None: ...
    @typing.overload
    def setCharacterStream(self, arg1: int | java.jint | java.lang.Integer, arg2: java.io.Reader, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setCharacterStream(self, arg1: str | java.lang.String, arg2: java.io.Reader, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setClob(self, arg1: int | java.jint | java.lang.Integer, arg2: java.io.Reader, /) -> None: ...
    @typing.overload
    def setClob(self, arg1: int | java.jint | java.lang.Integer, arg2: java.sql.Clob, /) -> None: ...
    @typing.overload
    def setClob(self, arg1: str | java.lang.String, arg2: java.io.Reader, /) -> None: ...
    @typing.overload
    def setClob(self, arg1: str | java.lang.String, arg2: java.sql.Clob, /) -> None: ...
    @typing.overload
    def setClob(self, arg1: int | java.jint | java.lang.Integer, arg2: java.io.Reader, arg3: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def setClob(self, arg1: str | java.lang.String, arg2: java.io.Reader, arg3: int | java.jlong | java.lang.Long, /) -> None: ...
    def setCommand(self, arg1: str | java.lang.String, /) -> None: ...
    def setConcurrency(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDataSourceName(self, arg1: str | java.lang.String, /) -> None: ...
    @typing.overload
    def setDate(self, arg1: int | java.jint | java.lang.Integer, arg2: java.sql.Date, /) -> None: ...
    @typing.overload
    def setDate(self, arg1: str | java.lang.String, arg2: java.sql.Date, /) -> None: ...
    @typing.overload
    def setDate(self, arg1: int | java.jint | java.lang.Integer, arg2: java.sql.Date, arg3: java.util.Calendar, /) -> None: ...
    @typing.overload
    def setDate(self, arg1: str | java.lang.String, arg2: java.sql.Date, arg3: java.util.Calendar, /) -> None: ...
    @typing.overload
    def setDouble(self, arg1: int | java.jint | java.lang.Integer, arg2: float | java.jdouble | java.lang.Double, /) -> None: ...
    @typing.overload
    def setDouble(self, arg1: str | java.lang.String, arg2: float | java.jdouble | java.lang.Double, /) -> None: ...
    def setEscapeProcessing(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def setFloat(self, arg1: int | java.jint | java.lang.Integer, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def setFloat(self, arg1: str | java.lang.String, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def setInt(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setInt(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setLong(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def setLong(self, arg1: str | java.lang.String, arg2: int | java.jlong | java.lang.Long, /) -> None: ...
    def setMaxFieldSize(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMaxRows(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setNCharacterStream(self, arg1: int | java.jint | java.lang.Integer, arg2: java.io.Reader, /) -> None: ...
    @typing.overload
    def setNCharacterStream(self, arg1: str | java.lang.String, arg2: java.io.Reader, /) -> None: ...
    @typing.overload
    def setNCharacterStream(self, arg1: int | java.jint | java.lang.Integer, arg2: java.io.Reader, arg3: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def setNCharacterStream(self, arg1: str | java.lang.String, arg2: java.io.Reader, arg3: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def setNClob(self, arg1: int | java.jint | java.lang.Integer, arg2: java.io.Reader, /) -> None: ...
    @typing.overload
    def setNClob(self, arg1: int | java.jint | java.lang.Integer, arg2: java.sql.NClob, /) -> None: ...
    @typing.overload
    def setNClob(self, arg1: str | java.lang.String, arg2: java.io.Reader, /) -> None: ...
    @typing.overload
    def setNClob(self, arg1: str | java.lang.String, arg2: java.sql.NClob, /) -> None: ...
    @typing.overload
    def setNClob(self, arg1: int | java.jint | java.lang.Integer, arg2: java.io.Reader, arg3: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def setNClob(self, arg1: str | java.lang.String, arg2: java.io.Reader, arg3: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def setNString(self, arg1: int | java.jint | java.lang.Integer, arg2: str | java.lang.String, /) -> None: ...
    @typing.overload
    def setNString(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> None: ...
    @typing.overload
    def setNull(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setNull(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setNull(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: str | java.lang.String, /) -> None: ...
    @typing.overload
    def setNull(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, arg3: str | java.lang.String, /) -> None: ...
    @typing.overload
    def setObject(self, arg1: int | java.jint | java.lang.Integer, arg2: java.lang.Object | int | bool | float | str, /) -> None: ...
    @typing.overload
    def setObject(self, arg1: str | java.lang.String, arg2: java.lang.Object | int | bool | float | str, /) -> None: ...
    @typing.overload
    def setObject(self, arg1: int | java.jint | java.lang.Integer, arg2: java.lang.Object | int | bool | float | str, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setObject(self, arg1: str | java.lang.String, arg2: java.lang.Object | int | bool | float | str, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setObject(self, arg1: int | java.jint | java.lang.Integer, arg2: java.lang.Object | int | bool | float | str, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setObject(self, arg1: str | java.lang.String, arg2: java.lang.Object | int | bool | float | str, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPassword(self, arg1: str | java.lang.String, /) -> None: ...
    def setQueryTimeout(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setReadOnly(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setRef(self, arg1: int | java.jint | java.lang.Integer, arg2: java.sql.Ref, /) -> None: ...
    @typing.overload
    def setRowId(self, arg1: int | java.jint | java.lang.Integer, arg2: java.sql.RowId, /) -> None: ...
    @typing.overload
    def setRowId(self, arg1: str | java.lang.String, arg2: java.sql.RowId, /) -> None: ...
    @typing.overload
    def setSQLXML(self, arg1: int | java.jint | java.lang.Integer, arg2: java.sql.SQLXML, /) -> None: ...
    @typing.overload
    def setSQLXML(self, arg1: str | java.lang.String, arg2: java.sql.SQLXML, /) -> None: ...
    @typing.overload
    def setShort(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jshort | java.lang.Short, /) -> None: ...
    @typing.overload
    def setShort(self, arg1: str | java.lang.String, arg2: int | java.jshort | java.lang.Short, /) -> None: ...
    @typing.overload
    def setString(self, arg1: int | java.jint | java.lang.Integer, arg2: str | java.lang.String, /) -> None: ...
    @typing.overload
    def setString(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> None: ...
    @typing.overload
    def setTime(self, arg1: int | java.jint | java.lang.Integer, arg2: java.sql.Time, /) -> None: ...
    @typing.overload
    def setTime(self, arg1: str | java.lang.String, arg2: java.sql.Time, /) -> None: ...
    @typing.overload
    def setTime(self, arg1: int | java.jint | java.lang.Integer, arg2: java.sql.Time, arg3: java.util.Calendar, /) -> None: ...
    @typing.overload
    def setTime(self, arg1: str | java.lang.String, arg2: java.sql.Time, arg3: java.util.Calendar, /) -> None: ...
    @typing.overload
    def setTimestamp(self, arg1: int | java.jint | java.lang.Integer, arg2: java.sql.Timestamp, /) -> None: ...
    @typing.overload
    def setTimestamp(self, arg1: str | java.lang.String, arg2: java.sql.Timestamp, /) -> None: ...
    @typing.overload
    def setTimestamp(self, arg1: int | java.jint | java.lang.Integer, arg2: java.sql.Timestamp, arg3: java.util.Calendar, /) -> None: ...
    @typing.overload
    def setTimestamp(self, arg1: str | java.lang.String, arg2: java.sql.Timestamp, arg3: java.util.Calendar, /) -> None: ...
    def setTransactionIsolation(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setType(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setTypeMap(self, arg1: java.util.Map[java.lang.String, typing.Type[java.lang.Object]], /) -> None: ...
    def setURL(self, arg1: int | java.jint | java.lang.Integer, arg2: java.net.URL, /) -> None: ...
    def setUrl(self, arg1: str | java.lang.String, /) -> None: ...
    def setUsername(self, arg1: str | java.lang.String, /) -> None: ...

class RowSetEvent(java.util.EventObject):
    def __init__(self, source: RowSet, /) -> None: ...

class RowSetInternal(java.lang.Object):
    def getConnection(self) -> java.sql.Connection: ...
    def getOriginal(self) -> java.sql.ResultSet: ...
    def getOriginalRow(self) -> java.sql.ResultSet: ...
    def getParams(self) -> java.chaquopy.JavaArray[java.lang.Object]: ...
    def setMetaData(self, arg1: RowSetMetaData, /) -> None: ...

class RowSetListener(java.util.EventListener):
    def cursorMoved(self, arg1: RowSetEvent, /) -> None: ...
    def rowChanged(self, arg1: RowSetEvent, /) -> None: ...
    def rowSetChanged(self, arg1: RowSetEvent, /) -> None: ...

class RowSetMetaData(java.sql.ResultSetMetaData):
    def setAutoIncrement(self, arg1: int | java.jint | java.lang.Integer, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setCaseSensitive(self, arg1: int | java.jint | java.lang.Integer, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setCatalogName(self, arg1: int | java.jint | java.lang.Integer, arg2: str | java.lang.String, /) -> None: ...
    def setColumnCount(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setColumnDisplaySize(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def setColumnLabel(self, arg1: int | java.jint | java.lang.Integer, arg2: str | java.lang.String, /) -> None: ...
    def setColumnName(self, arg1: int | java.jint | java.lang.Integer, arg2: str | java.lang.String, /) -> None: ...
    def setColumnType(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def setColumnTypeName(self, arg1: int | java.jint | java.lang.Integer, arg2: str | java.lang.String, /) -> None: ...
    def setCurrency(self, arg1: int | java.jint | java.lang.Integer, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setNullable(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def setPrecision(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def setScale(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSchemaName(self, arg1: int | java.jint | java.lang.Integer, arg2: str | java.lang.String, /) -> None: ...
    def setSearchable(self, arg1: int | java.jint | java.lang.Integer, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSigned(self, arg1: int | java.jint | java.lang.Integer, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setTableName(self, arg1: int | java.jint | java.lang.Integer, arg2: str | java.lang.String, /) -> None: ...

class RowSetReader(java.lang.Object):
    def readData(self, arg1: RowSetInternal, /) -> None: ...

class RowSetWriter(java.lang.Object):
    def writeData(self, arg1: RowSetInternal, /) -> bool: ...

class StatementEvent(java.util.EventObject):
    @typing.overload
    def __init__(self, con: PooledConnection, statement: java.sql.PreparedStatement, /) -> None: ...
    @typing.overload
    def __init__(self, con: PooledConnection, statement: java.sql.PreparedStatement, exception: java.sql.SQLException, /) -> None: ...
    def getSQLException(self) -> java.sql.SQLException: ...
    def getStatement(self) -> java.sql.PreparedStatement: ...

class StatementEventListener(java.util.EventListener):
    def statementClosed(self, arg1: StatementEvent, /) -> None: ...
    def statementErrorOccurred(self, arg1: StatementEvent, /) -> None: ...



import typing

import java.chaquopy
import java.lang
import java.math
import java.security
import javax.crypto
import javax.crypto.spec

class DHKey(java.lang.Object):
    def getParams(self) -> javax.crypto.spec.DHParameterSpec: ...

class DHPrivateKey(DHKey, java.security.PrivateKey):
    serialVersionUID: typing.ClassVar[int] = ...
    def getX(self) -> java.math.BigInteger: ...

class DHPublicKey(DHKey, java.security.PublicKey):
    serialVersionUID: typing.ClassVar[int] = ...
    def getY(self) -> java.math.BigInteger: ...

class PBEKey(javax.crypto.SecretKey):
    serialVersionUID: typing.ClassVar[int] = ...
    def getIterationCount(self) -> int: ...
    def getPassword(self) -> java.chaquopy.JavaArrayJChar: ...
    def getSalt(self) -> java.chaquopy.JavaArrayJByte: ...



import typing

import android.hardware.usb
import android.os
import java
import java.chaquopy
import java.lang

class MtpConstants(java.lang.Object):
    ASSOCIATION_TYPE_GENERIC_FOLDER: typing.ClassVar[int] = ...
    FORMAT_3GP_CONTAINER: typing.ClassVar[int] = ...
    FORMAT_AAC: typing.ClassVar[int] = ...
    FORMAT_ABSTRACT_AUDIO_ALBUM: typing.ClassVar[int] = ...
    FORMAT_ABSTRACT_AUDIO_PLAYLIST: typing.ClassVar[int] = ...
    FORMAT_ABSTRACT_AV_PLAYLIST: typing.ClassVar[int] = ...
    FORMAT_ABSTRACT_DOCUMENT: typing.ClassVar[int] = ...
    FORMAT_ABSTRACT_IMAGE_ALBUM: typing.ClassVar[int] = ...
    FORMAT_ABSTRACT_MEDIACAST: typing.ClassVar[int] = ...
    FORMAT_ABSTRACT_MULTIMEDIA_ALBUM: typing.ClassVar[int] = ...
    FORMAT_ABSTRACT_VIDEO_ALBUM: typing.ClassVar[int] = ...
    FORMAT_ABSTRACT_VIDEO_PLAYLIST: typing.ClassVar[int] = ...
    FORMAT_AIFF: typing.ClassVar[int] = ...
    FORMAT_ASF: typing.ClassVar[int] = ...
    FORMAT_ASSOCIATION: typing.ClassVar[int] = ...
    FORMAT_ASX_PLAYLIST: typing.ClassVar[int] = ...
    FORMAT_AUDIBLE: typing.ClassVar[int] = ...
    FORMAT_AVI: typing.ClassVar[int] = ...
    FORMAT_BMP: typing.ClassVar[int] = ...
    FORMAT_DEFINED: typing.ClassVar[int] = ...
    FORMAT_DNG: typing.ClassVar[int] = ...
    FORMAT_DPOF: typing.ClassVar[int] = ...
    FORMAT_EXECUTABLE: typing.ClassVar[int] = ...
    FORMAT_EXIF_JPEG: typing.ClassVar[int] = ...
    FORMAT_FLAC: typing.ClassVar[int] = ...
    FORMAT_GIF: typing.ClassVar[int] = ...
    FORMAT_HTML: typing.ClassVar[int] = ...
    FORMAT_JFIF: typing.ClassVar[int] = ...
    FORMAT_JP2: typing.ClassVar[int] = ...
    FORMAT_JPX: typing.ClassVar[int] = ...
    FORMAT_M3U_PLAYLIST: typing.ClassVar[int] = ...
    FORMAT_MP2: typing.ClassVar[int] = ...
    FORMAT_MP3: typing.ClassVar[int] = ...
    FORMAT_MP4_CONTAINER: typing.ClassVar[int] = ...
    FORMAT_MPEG: typing.ClassVar[int] = ...
    FORMAT_MPL_PLAYLIST: typing.ClassVar[int] = ...
    FORMAT_MS_EXCEL_SPREADSHEET: typing.ClassVar[int] = ...
    FORMAT_MS_POWERPOINT_PRESENTATION: typing.ClassVar[int] = ...
    FORMAT_MS_WORD_DOCUMENT: typing.ClassVar[int] = ...
    FORMAT_OGG: typing.ClassVar[int] = ...
    FORMAT_PICT: typing.ClassVar[int] = ...
    FORMAT_PLS_PLAYLIST: typing.ClassVar[int] = ...
    FORMAT_PNG: typing.ClassVar[int] = ...
    FORMAT_SCRIPT: typing.ClassVar[int] = ...
    FORMAT_TEXT: typing.ClassVar[int] = ...
    FORMAT_TIFF: typing.ClassVar[int] = ...
    FORMAT_TIFF_EP: typing.ClassVar[int] = ...
    FORMAT_UNDEFINED: typing.ClassVar[int] = ...
    FORMAT_UNDEFINED_AUDIO: typing.ClassVar[int] = ...
    FORMAT_UNDEFINED_COLLECTION: typing.ClassVar[int] = ...
    FORMAT_UNDEFINED_DOCUMENT: typing.ClassVar[int] = ...
    FORMAT_UNDEFINED_FIRMWARE: typing.ClassVar[int] = ...
    FORMAT_UNDEFINED_VIDEO: typing.ClassVar[int] = ...
    FORMAT_WAV: typing.ClassVar[int] = ...
    FORMAT_WINDOWS_IMAGE_FORMAT: typing.ClassVar[int] = ...
    FORMAT_WMA: typing.ClassVar[int] = ...
    FORMAT_WMV: typing.ClassVar[int] = ...
    FORMAT_WPL_PLAYLIST: typing.ClassVar[int] = ...
    FORMAT_XML_DOCUMENT: typing.ClassVar[int] = ...
    OPERATION_CLOSE_SESSION: typing.ClassVar[int] = ...
    OPERATION_COPY_OBJECT: typing.ClassVar[int] = ...
    OPERATION_DELETE_OBJECT: typing.ClassVar[int] = ...
    OPERATION_FORMAT_STORE: typing.ClassVar[int] = ...
    OPERATION_GET_DEVICE_INFO: typing.ClassVar[int] = ...
    OPERATION_GET_DEVICE_PROP_DESC: typing.ClassVar[int] = ...
    OPERATION_GET_DEVICE_PROP_VALUE: typing.ClassVar[int] = ...
    OPERATION_GET_NUM_OBJECTS: typing.ClassVar[int] = ...
    OPERATION_GET_OBJECT: typing.ClassVar[int] = ...
    OPERATION_GET_OBJECT_HANDLES: typing.ClassVar[int] = ...
    OPERATION_GET_OBJECT_INFO: typing.ClassVar[int] = ...
    OPERATION_GET_OBJECT_PROPS_SUPPORTED: typing.ClassVar[int] = ...
    OPERATION_GET_OBJECT_PROP_DESC: typing.ClassVar[int] = ...
    OPERATION_GET_OBJECT_PROP_VALUE: typing.ClassVar[int] = ...
    OPERATION_GET_OBJECT_REFERENCES: typing.ClassVar[int] = ...
    OPERATION_GET_PARTIAL_OBJECT: typing.ClassVar[int] = ...
    OPERATION_GET_PARTIAL_OBJECT_64: typing.ClassVar[int] = ...
    OPERATION_GET_STORAGE_INFO: typing.ClassVar[int] = ...
    OPERATION_GET_STORAGE_I_DS: typing.ClassVar[int] = ...
    OPERATION_GET_THUMB: typing.ClassVar[int] = ...
    OPERATION_INITIATE_CAPTURE: typing.ClassVar[int] = ...
    OPERATION_INITIATE_OPEN_CAPTURE: typing.ClassVar[int] = ...
    OPERATION_MOVE_OBJECT: typing.ClassVar[int] = ...
    OPERATION_OPEN_SESSION: typing.ClassVar[int] = ...
    OPERATION_POWER_DOWN: typing.ClassVar[int] = ...
    OPERATION_RESET_DEVICE: typing.ClassVar[int] = ...
    OPERATION_RESET_DEVICE_PROP_VALUE: typing.ClassVar[int] = ...
    OPERATION_SELF_TEST: typing.ClassVar[int] = ...
    OPERATION_SEND_OBJECT: typing.ClassVar[int] = ...
    OPERATION_SEND_OBJECT_INFO: typing.ClassVar[int] = ...
    OPERATION_SET_DEVICE_PROP_VALUE: typing.ClassVar[int] = ...
    OPERATION_SET_OBJECT_PROP_VALUE: typing.ClassVar[int] = ...
    OPERATION_SET_OBJECT_PROTECTION: typing.ClassVar[int] = ...
    OPERATION_SET_OBJECT_REFERENCES: typing.ClassVar[int] = ...
    OPERATION_SKIP: typing.ClassVar[int] = ...
    OPERATION_TERMINATE_OPEN_CAPTURE: typing.ClassVar[int] = ...
    PROTECTION_STATUS_NONE: typing.ClassVar[int] = ...
    PROTECTION_STATUS_NON_TRANSFERABLE_DATA: typing.ClassVar[int] = ...
    PROTECTION_STATUS_READ_ONLY: typing.ClassVar[int] = ...
    PROTECTION_STATUS_READ_ONLY_DATA: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    @staticmethod
    def isAbstractObject(format: int | java.jint | java.lang.Integer, /) -> bool: ...

class MtpDevice(java.lang.Object):
    def __init__(self, device: android.hardware.usb.UsbDevice, /) -> None: ...
    def close(self) -> None: ...
    def deleteObject(self, objectHandle: int | java.jint | java.lang.Integer, /) -> bool: ...
    def finalize(self) -> None: ...
    def getDeviceId(self) -> int: ...
    def getDeviceInfo(self) -> MtpDeviceInfo | None: ...
    def getDeviceName(self) -> str: ...
    def getObject(self, objectHandle: int | java.jint | java.lang.Integer, objectSize: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte | None: ...
    def getObjectHandles(self, storageId: int | java.jint | java.lang.Integer, format: int | java.jint | java.lang.Integer, objectHandle: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt | None: ...
    def getObjectInfo(self, objectHandle: int | java.jint | java.lang.Integer, /) -> MtpObjectInfo | None: ...
    def getParent(self, objectHandle: int | java.jint | java.lang.Integer, /) -> int: ...
    def getPartialObject(self, objectHandle: int | java.jint | java.lang.Integer, offset: int | java.jlong | java.lang.Long, size: int | java.jlong | java.lang.Long, buffer: java.chaquopy.JavaArrayJByte, /) -> int: ...
    def getPartialObject64(self, objectHandle: int | java.jint | java.lang.Integer, offset: int | java.jlong | java.lang.Long, size: int | java.jlong | java.lang.Long, buffer: java.chaquopy.JavaArrayJByte, /) -> int: ...
    def getStorageId(self, objectHandle: int | java.jint | java.lang.Integer, /) -> int: ...
    def getStorageIds(self) -> java.chaquopy.JavaArrayJInt | None: ...
    def getStorageInfo(self, storageId: int | java.jint | java.lang.Integer, /) -> MtpStorageInfo | None: ...
    def getThumbnail(self, objectHandle: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte | None: ...
    @typing.overload
    def importFile(self, objectHandle: int | java.jint | java.lang.Integer, descriptor: android.os.ParcelFileDescriptor, /) -> bool: ...
    @typing.overload
    def importFile(self, objectHandle: int | java.jint | java.lang.Integer, destPath: str | java.lang.String, /) -> bool: ...
    def open(self, connection: android.hardware.usb.UsbDeviceConnection, /) -> bool: ...
    def readEvent(self, signal: android.os.CancellationSignal, /) -> MtpEvent: ...
    def sendObject(self, objectHandle: int | java.jint | java.lang.Integer, size: int | java.jlong | java.lang.Long, descriptor: android.os.ParcelFileDescriptor, /) -> bool: ...
    def sendObjectInfo(self, info: MtpObjectInfo, /) -> MtpObjectInfo | None: ...
    def toString(self) -> str: ...

class MtpDeviceInfo(java.lang.Object):
    def getEventsSupported(self) -> java.chaquopy.JavaArrayJInt | None: ...
    def getManufacturer(self) -> str: ...
    def getModel(self) -> str: ...
    def getOperationsSupported(self) -> java.chaquopy.JavaArrayJInt | None: ...
    def getSerialNumber(self) -> str: ...
    def getVersion(self) -> str: ...
    def isEventSupported(self, code: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isOperationSupported(self, code: int | java.jint | java.lang.Integer, /) -> bool: ...

class MtpEvent(java.lang.Object):
    EVENT_CANCEL_TRANSACTION: typing.ClassVar[int] = ...
    EVENT_CAPTURE_COMPLETE: typing.ClassVar[int] = ...
    EVENT_DEVICE_INFO_CHANGED: typing.ClassVar[int] = ...
    EVENT_DEVICE_PROP_CHANGED: typing.ClassVar[int] = ...
    EVENT_DEVICE_RESET: typing.ClassVar[int] = ...
    EVENT_OBJECT_ADDED: typing.ClassVar[int] = ...
    EVENT_OBJECT_INFO_CHANGED: typing.ClassVar[int] = ...
    EVENT_OBJECT_PROP_CHANGED: typing.ClassVar[int] = ...
    EVENT_OBJECT_PROP_DESC_CHANGED: typing.ClassVar[int] = ...
    EVENT_OBJECT_REFERENCES_CHANGED: typing.ClassVar[int] = ...
    EVENT_OBJECT_REMOVED: typing.ClassVar[int] = ...
    EVENT_REQUEST_OBJECT_TRANSFER: typing.ClassVar[int] = ...
    EVENT_STORAGE_INFO_CHANGED: typing.ClassVar[int] = ...
    EVENT_STORE_ADDED: typing.ClassVar[int] = ...
    EVENT_STORE_FULL: typing.ClassVar[int] = ...
    EVENT_STORE_REMOVED: typing.ClassVar[int] = ...
    EVENT_UNDEFINED: typing.ClassVar[int] = ...
    EVENT_UNREPORTED_STATUS: typing.ClassVar[int] = ...
    def getDevicePropCode(self) -> int: ...
    def getEventCode(self) -> int: ...
    def getObjectFormatCode(self) -> int: ...
    def getObjectHandle(self) -> int: ...
    def getObjectPropCode(self) -> int: ...
    def getParameter1(self) -> int: ...
    def getParameter2(self) -> int: ...
    def getParameter3(self) -> int: ...
    def getStorageId(self) -> int: ...
    def getTransactionId(self) -> int: ...

class MtpObjectInfo(java.lang.Object):
    def getAssociationDesc(self) -> int: ...
    def getAssociationType(self) -> int: ...
    def getCompressedSize(self) -> int: ...
    def getCompressedSizeLong(self) -> int: ...
    def getDateCreated(self) -> int: ...
    def getDateModified(self) -> int: ...
    def getFormat(self) -> int: ...
    def getImagePixDepth(self) -> int: ...
    def getImagePixDepthLong(self) -> int: ...
    def getImagePixHeight(self) -> int: ...
    def getImagePixHeightLong(self) -> int: ...
    def getImagePixWidth(self) -> int: ...
    def getImagePixWidthLong(self) -> int: ...
    def getKeywords(self) -> str: ...
    def getName(self) -> str: ...
    def getObjectHandle(self) -> int: ...
    def getParent(self) -> int: ...
    def getProtectionStatus(self) -> int: ...
    def getSequenceNumber(self) -> int: ...
    def getSequenceNumberLong(self) -> int: ...
    def getStorageId(self) -> int: ...
    def getThumbCompressedSize(self) -> int: ...
    def getThumbCompressedSizeLong(self) -> int: ...
    def getThumbFormat(self) -> int: ...
    def getThumbPixHeight(self) -> int: ...
    def getThumbPixHeightLong(self) -> int: ...
    def getThumbPixWidth(self) -> int: ...
    def getThumbPixWidthLong(self) -> int: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, objectInfo: MtpObjectInfo, /) -> None: ...
        def build(self) -> MtpObjectInfo: ...
        def setAssociationDesc(self, value: int | java.jint | java.lang.Integer, /) -> MtpObjectInfo.Builder: ...
        def setAssociationType(self, value: int | java.jint | java.lang.Integer, /) -> MtpObjectInfo.Builder: ...
        def setCompressedSize(self, value: int | java.jlong | java.lang.Long, /) -> MtpObjectInfo.Builder: ...
        def setDateCreated(self, value: int | java.jlong | java.lang.Long, /) -> MtpObjectInfo.Builder: ...
        def setDateModified(self, value: int | java.jlong | java.lang.Long, /) -> MtpObjectInfo.Builder: ...
        def setFormat(self, value: int | java.jint | java.lang.Integer, /) -> MtpObjectInfo.Builder: ...
        def setImagePixDepth(self, value: int | java.jlong | java.lang.Long, /) -> MtpObjectInfo.Builder: ...
        def setImagePixHeight(self, value: int | java.jlong | java.lang.Long, /) -> MtpObjectInfo.Builder: ...
        def setImagePixWidth(self, value: int | java.jlong | java.lang.Long, /) -> MtpObjectInfo.Builder: ...
        def setKeywords(self, value: str | java.lang.String, /) -> MtpObjectInfo.Builder: ...
        def setName(self, value: str | java.lang.String, /) -> MtpObjectInfo.Builder: ...
        def setObjectHandle(self, value: int | java.jint | java.lang.Integer, /) -> MtpObjectInfo.Builder: ...
        def setParent(self, value: int | java.jint | java.lang.Integer, /) -> MtpObjectInfo.Builder: ...
        def setProtectionStatus(self, value: int | java.jint | java.lang.Integer, /) -> MtpObjectInfo.Builder: ...
        def setSequenceNumber(self, value: int | java.jlong | java.lang.Long, /) -> MtpObjectInfo.Builder: ...
        def setStorageId(self, value: int | java.jint | java.lang.Integer, /) -> MtpObjectInfo.Builder: ...
        def setThumbCompressedSize(self, value: int | java.jlong | java.lang.Long, /) -> MtpObjectInfo.Builder: ...
        def setThumbFormat(self, value: int | java.jint | java.lang.Integer, /) -> MtpObjectInfo.Builder: ...
        def setThumbPixHeight(self, value: int | java.jlong | java.lang.Long, /) -> MtpObjectInfo.Builder: ...
        def setThumbPixWidth(self, value: int | java.jlong | java.lang.Long, /) -> MtpObjectInfo.Builder: ...

class MtpStorageInfo(java.lang.Object):
    def getDescription(self) -> str: ...
    def getFreeSpace(self) -> int: ...
    def getMaxCapacity(self) -> int: ...
    def getStorageId(self) -> int: ...
    def getVolumeIdentifier(self) -> str: ...



import java
import java.lang
import java.util.concurrent

class AdvancedProtectionManager(java.lang.Object):
    def isAdvancedProtectionEnabled(self) -> bool: ...
    def registerAdvancedProtectionCallback(self, executor: java.util.concurrent.Executor, callback: AdvancedProtectionManager.Callback, /) -> None: ...
    def unregisterAdvancedProtectionCallback(self, callback: AdvancedProtectionManager.Callback, /) -> None: ...

    class Callback(java.lang.Object):
        def onAdvancedProtectionChanged(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...



import typing

import android.icu.text
import android.icu.util
import java
import java.chaquopy
import java.lang
import java.math
import java.text
import java.util

class CompactNotation(Notation): ...

class CurrencyPrecision(Precision):
    def withCurrency(self, currency: android.icu.util.Currency, /) -> Precision: ...

class FormattedNumber(android.icu.text.FormattedValue):
    _appendTo__A = typing.TypeVar('_appendTo__A')  # <A>
    def appendTo(self, appendable: _appendTo__A, /) -> _appendTo__A: ...
    def charAt(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    def getNounClass(self) -> android.icu.text.DisplayOptions.NounClass: ...
    def getOutputUnit(self) -> android.icu.util.MeasureUnit: ...
    def length(self) -> int: ...
    def nextPosition(self, cfpos: android.icu.text.ConstrainedFieldPosition, /) -> bool: ...
    def subSequence(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    def toBigDecimal(self) -> java.math.BigDecimal: ...
    def toCharacterIterator(self) -> java.text.AttributedCharacterIterator: ...
    def toString(self) -> str: ...

class FormattedNumberRange(android.icu.text.FormattedValue):
    _appendTo__A = typing.TypeVar('_appendTo__A')  # <A>
    def appendTo(self, appendable: _appendTo__A, /) -> _appendTo__A: ...
    def charAt(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getFirstBigDecimal(self) -> java.math.BigDecimal: ...
    def getIdentityResult(self) -> NumberRangeFormatter.RangeIdentityResult: ...
    def getSecondBigDecimal(self) -> java.math.BigDecimal: ...
    def hashCode(self) -> int: ...
    def length(self) -> int: ...
    def nextPosition(self, cfpos: android.icu.text.ConstrainedFieldPosition, /) -> bool: ...
    def subSequence(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    def toCharacterIterator(self) -> java.text.AttributedCharacterIterator: ...
    def toString(self) -> str: ...

class FractionPrecision(Precision):
    def withMaxDigits(self, maxSignificantDigits: int | java.jint | java.lang.Integer, /) -> Precision: ...
    def withMinDigits(self, minSignificantDigits: int | java.jint | java.lang.Integer, /) -> Precision: ...
    def withSignificantDigits(self, minSignificantDigits: int | java.jint | java.lang.Integer, maxSignificantDigits: int | java.jint | java.lang.Integer, priority: NumberFormatter.RoundingPriority, /) -> Precision: ...

class IntegerWidth(java.lang.Object):
    def truncateAt(self, maxInt: int | java.jint | java.lang.Integer, /) -> IntegerWidth: ...
    @staticmethod
    def zeroFillTo(minInt: int | java.jint | java.lang.Integer, /) -> IntegerWidth: ...

class LocalizedNumberFormatter(NumberFormatterSettings[LocalizedNumberFormatter]):
    @typing.overload
    def format(self, input: float | java.jdouble | java.lang.Double, /) -> FormattedNumber: ...
    @typing.overload
    def format(self, input: int | java.jlong | java.lang.Long, /) -> FormattedNumber: ...
    @typing.overload
    def format(self, input: android.icu.util.Measure, /) -> FormattedNumber: ...
    @typing.overload
    def format(self, input: java.lang.Number, /) -> FormattedNumber: ...
    def toFormat(self) -> java.text.Format: ...
    def withoutLocale(self) -> UnlocalizedNumberFormatter: ...

class LocalizedNumberRangeFormatter(NumberRangeFormatterSettings[LocalizedNumberRangeFormatter]):
    @typing.overload
    def formatRange(self, first: float | java.jdouble | java.lang.Double, second: float | java.jdouble | java.lang.Double, /) -> FormattedNumberRange: ...
    @typing.overload
    def formatRange(self, first: int | java.jint | java.lang.Integer, second: int | java.jint | java.lang.Integer, /) -> FormattedNumberRange: ...
    @typing.overload
    def formatRange(self, first: java.lang.Number, second: java.lang.Number, /) -> FormattedNumberRange: ...
    def withoutLocale(self) -> UnlocalizedNumberRangeFormatter: ...

class Notation(java.lang.Object):
    @staticmethod
    def compactLong() -> CompactNotation: ...
    @staticmethod
    def compactShort() -> CompactNotation: ...
    @staticmethod
    def engineering() -> ScientificNotation: ...
    @staticmethod
    def scientific() -> ScientificNotation: ...
    @staticmethod
    def simple() -> SimpleNotation: ...

class NumberFormatter(java.lang.Object):
    @typing.overload
    @staticmethod
    def withLocale(locale: android.icu.util.ULocale, /) -> LocalizedNumberFormatter: ...
    @typing.overload
    @staticmethod
    def withLocale(locale: java.util.Locale, /) -> LocalizedNumberFormatter: ...
    @staticmethod
    def with_() -> UnlocalizedNumberFormatter: ...

    class UnitWidth(java.lang.Enum[NumberFormatter.UnitWidth]):
        FORMAL: typing.ClassVar[NumberFormatter.UnitWidth] = ...
        FULL_NAME: typing.ClassVar[NumberFormatter.UnitWidth] = ...
        HIDDEN: typing.ClassVar[NumberFormatter.UnitWidth] = ...
        ISO_CODE: typing.ClassVar[NumberFormatter.UnitWidth] = ...
        NARROW: typing.ClassVar[NumberFormatter.UnitWidth] = ...
        SHORT: typing.ClassVar[NumberFormatter.UnitWidth] = ...
        VARIANT: typing.ClassVar[NumberFormatter.UnitWidth] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> NumberFormatter.UnitWidth: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[NumberFormatter.UnitWidth]: ...

    class TrailingZeroDisplay(java.lang.Enum[NumberFormatter.TrailingZeroDisplay]):
        AUTO: typing.ClassVar[NumberFormatter.TrailingZeroDisplay] = ...
        HIDE_IF_WHOLE: typing.ClassVar[NumberFormatter.TrailingZeroDisplay] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> NumberFormatter.TrailingZeroDisplay: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[NumberFormatter.TrailingZeroDisplay]: ...

    class SignDisplay(java.lang.Enum[NumberFormatter.SignDisplay]):
        ACCOUNTING: typing.ClassVar[NumberFormatter.SignDisplay] = ...
        ACCOUNTING_ALWAYS: typing.ClassVar[NumberFormatter.SignDisplay] = ...
        ACCOUNTING_EXCEPT_ZERO: typing.ClassVar[NumberFormatter.SignDisplay] = ...
        ACCOUNTING_NEGATIVE: typing.ClassVar[NumberFormatter.SignDisplay] = ...
        ALWAYS: typing.ClassVar[NumberFormatter.SignDisplay] = ...
        AUTO: typing.ClassVar[NumberFormatter.SignDisplay] = ...
        EXCEPT_ZERO: typing.ClassVar[NumberFormatter.SignDisplay] = ...
        NEGATIVE: typing.ClassVar[NumberFormatter.SignDisplay] = ...
        NEVER: typing.ClassVar[NumberFormatter.SignDisplay] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> NumberFormatter.SignDisplay: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[NumberFormatter.SignDisplay]: ...

    class RoundingPriority(java.lang.Enum[NumberFormatter.RoundingPriority]):
        RELAXED: typing.ClassVar[NumberFormatter.RoundingPriority] = ...
        STRICT: typing.ClassVar[NumberFormatter.RoundingPriority] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> NumberFormatter.RoundingPriority: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[NumberFormatter.RoundingPriority]: ...

    class GroupingStrategy(java.lang.Enum[NumberFormatter.GroupingStrategy]):
        AUTO: typing.ClassVar[NumberFormatter.GroupingStrategy] = ...
        MIN2: typing.ClassVar[NumberFormatter.GroupingStrategy] = ...
        OFF: typing.ClassVar[NumberFormatter.GroupingStrategy] = ...
        ON_ALIGNED: typing.ClassVar[NumberFormatter.GroupingStrategy] = ...
        THOUSANDS: typing.ClassVar[NumberFormatter.GroupingStrategy] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> NumberFormatter.GroupingStrategy: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[NumberFormatter.GroupingStrategy]: ...

    class DecimalSeparatorDisplay(java.lang.Enum[NumberFormatter.DecimalSeparatorDisplay]):
        ALWAYS: typing.ClassVar[NumberFormatter.DecimalSeparatorDisplay] = ...
        AUTO: typing.ClassVar[NumberFormatter.DecimalSeparatorDisplay] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> NumberFormatter.DecimalSeparatorDisplay: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[NumberFormatter.DecimalSeparatorDisplay]: ...

_NumberFormatterSettings__T = typing.TypeVar('_NumberFormatterSettings__T', bound=NumberFormatterSettings[java.lang.Object])  # <T>
class NumberFormatterSettings(java.lang.Object, typing.Generic[_NumberFormatterSettings__T]):
    def decimal(self, style: NumberFormatter.DecimalSeparatorDisplay, /) -> _NumberFormatterSettings__T: ...
    def displayOptions(self, displayOptions: android.icu.text.DisplayOptions, /) -> _NumberFormatterSettings__T: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def grouping(self, strategy: NumberFormatter.GroupingStrategy, /) -> _NumberFormatterSettings__T: ...
    def hashCode(self) -> int: ...
    def integerWidth(self, style: IntegerWidth, /) -> _NumberFormatterSettings__T: ...
    def notation(self, notation: Notation, /) -> _NumberFormatterSettings__T: ...
    def perUnit(self, perUnit: android.icu.util.MeasureUnit, /) -> _NumberFormatterSettings__T: ...
    def precision(self, precision: Precision, /) -> _NumberFormatterSettings__T: ...
    def roundingMode(self, roundingMode: java.math.RoundingMode, /) -> _NumberFormatterSettings__T: ...
    def scale(self, scale: Scale, /) -> _NumberFormatterSettings__T: ...
    def sign(self, style: NumberFormatter.SignDisplay, /) -> _NumberFormatterSettings__T: ...
    @typing.overload
    def symbols(self, symbols: android.icu.text.DecimalFormatSymbols, /) -> _NumberFormatterSettings__T: ...
    @typing.overload
    def symbols(self, ns: android.icu.text.NumberingSystem, /) -> _NumberFormatterSettings__T: ...
    def unit(self, unit: android.icu.util.MeasureUnit, /) -> _NumberFormatterSettings__T: ...
    def unitWidth(self, style: NumberFormatter.UnitWidth, /) -> _NumberFormatterSettings__T: ...
    def usage(self, usage: str | java.lang.String, /) -> _NumberFormatterSettings__T: ...

class NumberRangeFormatter(java.lang.Object):
    @typing.overload
    @staticmethod
    def withLocale(locale: android.icu.util.ULocale, /) -> LocalizedNumberRangeFormatter: ...
    @typing.overload
    @staticmethod
    def withLocale(locale: java.util.Locale, /) -> LocalizedNumberRangeFormatter: ...
    @staticmethod
    def with_() -> UnlocalizedNumberRangeFormatter: ...

    class RangeIdentityResult(java.lang.Enum[NumberRangeFormatter.RangeIdentityResult]):
        EQUAL_AFTER_ROUNDING: typing.ClassVar[NumberRangeFormatter.RangeIdentityResult] = ...
        EQUAL_BEFORE_ROUNDING: typing.ClassVar[NumberRangeFormatter.RangeIdentityResult] = ...
        NOT_EQUAL: typing.ClassVar[NumberRangeFormatter.RangeIdentityResult] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> NumberRangeFormatter.RangeIdentityResult: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[NumberRangeFormatter.RangeIdentityResult]: ...

    class RangeIdentityFallback(java.lang.Enum[NumberRangeFormatter.RangeIdentityFallback]):
        APPROXIMATELY: typing.ClassVar[NumberRangeFormatter.RangeIdentityFallback] = ...
        APPROXIMATELY_OR_SINGLE_VALUE: typing.ClassVar[NumberRangeFormatter.RangeIdentityFallback] = ...
        RANGE: typing.ClassVar[NumberRangeFormatter.RangeIdentityFallback] = ...
        SINGLE_VALUE: typing.ClassVar[NumberRangeFormatter.RangeIdentityFallback] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> NumberRangeFormatter.RangeIdentityFallback: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[NumberRangeFormatter.RangeIdentityFallback]: ...

    class RangeCollapse(java.lang.Enum[NumberRangeFormatter.RangeCollapse]):
        ALL: typing.ClassVar[NumberRangeFormatter.RangeCollapse] = ...
        AUTO: typing.ClassVar[NumberRangeFormatter.RangeCollapse] = ...
        NONE: typing.ClassVar[NumberRangeFormatter.RangeCollapse] = ...
        UNIT: typing.ClassVar[NumberRangeFormatter.RangeCollapse] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> NumberRangeFormatter.RangeCollapse: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[NumberRangeFormatter.RangeCollapse]: ...

_NumberRangeFormatterSettings__T = typing.TypeVar('_NumberRangeFormatterSettings__T', bound=NumberRangeFormatterSettings[java.lang.Object])  # <T>
class NumberRangeFormatterSettings(java.lang.Object, typing.Generic[_NumberRangeFormatterSettings__T]):
    def collapse(self, collapse: NumberRangeFormatter.RangeCollapse, /) -> _NumberRangeFormatterSettings__T: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    def identityFallback(self, identityFallback: NumberRangeFormatter.RangeIdentityFallback, /) -> _NumberRangeFormatterSettings__T: ...
    def numberFormatterBoth(self, formatter: UnlocalizedNumberFormatter, /) -> _NumberRangeFormatterSettings__T: ...
    def numberFormatterFirst(self, formatterFirst: UnlocalizedNumberFormatter, /) -> _NumberRangeFormatterSettings__T: ...
    def numberFormatterSecond(self, formatterSecond: UnlocalizedNumberFormatter, /) -> _NumberRangeFormatterSettings__T: ...

class Precision(java.lang.Object):
    @staticmethod
    def currency(currencyUsage: android.icu.util.Currency.CurrencyUsage, /) -> CurrencyPrecision: ...
    @staticmethod
    def fixedFraction(minMaxFractionPlaces: int | java.jint | java.lang.Integer, /) -> FractionPrecision: ...
    @staticmethod
    def fixedSignificantDigits(minMaxSignificantDigits: int | java.jint | java.lang.Integer, /) -> Precision: ...
    @staticmethod
    def increment(roundingIncrement: java.math.BigDecimal, /) -> Precision: ...
    @staticmethod
    def integer() -> FractionPrecision: ...
    @staticmethod
    def maxFraction(maxFractionPlaces: int | java.jint | java.lang.Integer, /) -> FractionPrecision: ...
    @staticmethod
    def maxSignificantDigits(maxSignificantDigits: int | java.jint | java.lang.Integer, /) -> Precision: ...
    @staticmethod
    def minFraction(minFractionPlaces: int | java.jint | java.lang.Integer, /) -> FractionPrecision: ...
    @staticmethod
    def minMaxFraction(minFractionPlaces: int | java.jint | java.lang.Integer, maxFractionPlaces: int | java.jint | java.lang.Integer, /) -> FractionPrecision: ...
    @staticmethod
    def minMaxSignificantDigits(minSignificantDigits: int | java.jint | java.lang.Integer, maxSignificantDigits: int | java.jint | java.lang.Integer, /) -> Precision: ...
    @staticmethod
    def minSignificantDigits(minSignificantDigits: int | java.jint | java.lang.Integer, /) -> Precision: ...
    def trailingZeroDisplay(self, trailingZeroDisplay: NumberFormatter.TrailingZeroDisplay, /) -> Precision: ...
    @staticmethod
    def unlimited() -> Precision: ...

class Scale(java.lang.Object):
    @staticmethod
    def byBigDecimal(multiplicand: java.math.BigDecimal, /) -> Scale: ...
    @staticmethod
    def byDouble(multiplicand: float | java.jdouble | java.lang.Double, /) -> Scale: ...
    @staticmethod
    def byDoubleAndPowerOfTen(multiplicand: float | java.jdouble | java.lang.Double, power: int | java.jint | java.lang.Integer, /) -> Scale: ...
    @staticmethod
    def none() -> Scale: ...
    @staticmethod
    def powerOfTen(power: int | java.jint | java.lang.Integer, /) -> Scale: ...

class ScientificNotation(Notation):
    def withExponentSignDisplay(self, exponentSignDisplay: NumberFormatter.SignDisplay, /) -> ScientificNotation: ...
    def withMinExponentDigits(self, minExponentDigits: int | java.jint | java.lang.Integer, /) -> ScientificNotation: ...

class SimpleNotation(Notation): ...

class UnlocalizedNumberFormatter(NumberFormatterSettings[UnlocalizedNumberFormatter]):
    @typing.overload
    def locale(self, locale: android.icu.util.ULocale, /) -> LocalizedNumberFormatter: ...
    @typing.overload
    def locale(self, locale: java.util.Locale, /) -> LocalizedNumberFormatter: ...

class UnlocalizedNumberRangeFormatter(NumberRangeFormatterSettings[UnlocalizedNumberRangeFormatter]):
    @typing.overload
    def locale(self, locale: android.icu.util.ULocale, /) -> LocalizedNumberRangeFormatter: ...
    @typing.overload
    def locale(self, locale: java.util.Locale, /) -> LocalizedNumberRangeFormatter: ...



import typing

import java
import java.io
import java.lang
import java.util
import javax.xml.namespace
import org.xml.sax

class XPath(java.lang.Object):
    def compile(self, arg1: str | java.lang.String, /) -> XPathExpression: ...
    @typing.overload
    def evaluate(self, arg1: str | java.lang.String, arg2: java.lang.Object | int | bool | float | str, /) -> str: ...
    @typing.overload
    def evaluate(self, arg1: str | java.lang.String, arg2: org.xml.sax.InputSource, /) -> str: ...
    @typing.overload
    def evaluate(self, arg1: str | java.lang.String, arg2: java.lang.Object | int | bool | float | str, arg3: javax.xml.namespace.QName, /) -> java.lang.Object: ...
    @typing.overload
    def evaluate(self, arg1: str | java.lang.String, arg2: org.xml.sax.InputSource, arg3: javax.xml.namespace.QName, /) -> java.lang.Object: ...
    def getNamespaceContext(self) -> javax.xml.namespace.NamespaceContext: ...
    def getXPathFunctionResolver(self) -> XPathFunctionResolver: ...
    def getXPathVariableResolver(self) -> XPathVariableResolver: ...
    def reset(self) -> None: ...
    def setNamespaceContext(self, arg1: javax.xml.namespace.NamespaceContext, /) -> None: ...
    def setXPathFunctionResolver(self, arg1: XPathFunctionResolver, /) -> None: ...
    def setXPathVariableResolver(self, arg1: XPathVariableResolver, /) -> None: ...

class XPathConstants(java.lang.Object):
    BOOLEAN: typing.ClassVar[javax.xml.namespace.QName] = ...
    DOM_OBJECT_MODEL: typing.ClassVar[str] = ...
    NODE: typing.ClassVar[javax.xml.namespace.QName] = ...
    NODESET: typing.ClassVar[javax.xml.namespace.QName] = ...
    NUMBER: typing.ClassVar[javax.xml.namespace.QName] = ...
    STRING: typing.ClassVar[javax.xml.namespace.QName] = ...

class XPathException(java.lang.Exception):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    def getCause(self) -> java.lang.Throwable: ...
    @typing.overload
    def printStackTrace(self) -> None: ...
    @typing.overload
    def printStackTrace(self, s: java.io.PrintStream, /) -> None: ...
    @typing.overload
    def printStackTrace(self, s: java.io.PrintWriter, /) -> None: ...

class XPathExpression(java.lang.Object):
    @typing.overload
    def evaluate(self, arg1: java.lang.Object | int | bool | float | str, /) -> str: ...
    @typing.overload
    def evaluate(self, arg1: org.xml.sax.InputSource, /) -> str: ...
    @typing.overload
    def evaluate(self, arg1: java.lang.Object | int | bool | float | str, arg2: javax.xml.namespace.QName, /) -> java.lang.Object: ...
    @typing.overload
    def evaluate(self, arg1: org.xml.sax.InputSource, arg2: javax.xml.namespace.QName, /) -> java.lang.Object: ...

class XPathExpressionException(XPathException):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...

class XPathFactory(java.lang.Object):
    DEFAULT_OBJECT_MODEL_URI: typing.ClassVar[str] = ...
    DEFAULT_PROPERTY_NAME: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def getFeature(self, arg1: str | java.lang.String, /) -> bool: ...
    def isObjectModelSupported(self, arg1: str | java.lang.String, /) -> bool: ...
    @typing.overload
    @staticmethod
    def newInstance() -> XPathFactory: ...
    @typing.overload
    @staticmethod
    def newInstance(uri: str | java.lang.String, /) -> XPathFactory: ...
    @typing.overload
    @staticmethod
    def newInstance(uri: str | java.lang.String, factoryClassName: str | java.lang.String, classLoader: java.lang.ClassLoader, /) -> XPathFactory: ...
    def newXPath(self) -> XPath: ...
    def setFeature(self, arg1: str | java.lang.String, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setXPathFunctionResolver(self, arg1: XPathFunctionResolver, /) -> None: ...
    def setXPathVariableResolver(self, arg1: XPathVariableResolver, /) -> None: ...

class XPathFactoryConfigurationException(XPathException):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...

class XPathFunction(java.lang.Object):
    def evaluate(self, arg1: java.util.List, /) -> java.lang.Object: ...

class XPathFunctionException(XPathExpressionException):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...

class XPathFunctionResolver(java.lang.Object):
    def resolveFunction(self, arg1: javax.xml.namespace.QName, arg2: int | java.jint | java.lang.Integer, /) -> XPathFunction: ...

class XPathVariableResolver(java.lang.Object):
    def resolveVariable(self, arg1: javax.xml.namespace.QName, /) -> java.lang.Object: ...
